Class: Aws::DirectConnect::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DirectConnect::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-directconnect/client.rb
Overview
An API client for DirectConnect. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DirectConnect::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_direct_connect_gateway_association_proposal(params = {}) ⇒ Types::AcceptDirectConnectGatewayAssociationProposalResult
Accepts a proposal request to attach a virtual private gateway or transit gateway to a Direct Connect gateway.
-
#allocate_connection_on_interconnect(params = {}) ⇒ Types::Connection
Deprecated.
-
#allocate_hosted_connection(params = {}) ⇒ Types::Connection
Creates a hosted connection on the specified interconnect or a link aggregation group (LAG) of interconnects.
-
#allocate_private_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Provisions a private virtual interface to be owned by the specified Amazon Web Services account.
-
#allocate_public_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Provisions a public virtual interface to be owned by the specified Amazon Web Services account.
-
#allocate_transit_virtual_interface(params = {}) ⇒ Types::AllocateTransitVirtualInterfaceResult
Provisions a transit virtual interface to be owned by the specified Amazon Web Services account.
-
#associate_connection_with_lag(params = {}) ⇒ Types::Connection
Associates an existing connection with a link aggregation group (LAG).
-
#associate_hosted_connection(params = {}) ⇒ Types::Connection
Associates a hosted connection and its virtual interfaces with a link aggregation group (LAG) or interconnect.
-
#associate_mac_sec_key(params = {}) ⇒ Types::AssociateMacSecKeyResponse
Associates a MAC Security (MACsec) Connection Key Name (CKN)/ Connectivity Association Key (CAK) pair with an Direct Connect dedicated connection.
-
#associate_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Associates a virtual interface with a specified link aggregation group (LAG) or connection.
-
#confirm_connection(params = {}) ⇒ Types::ConfirmConnectionResponse
Confirms the creation of the specified hosted connection on an interconnect.
-
#confirm_customer_agreement(params = {}) ⇒ Types::ConfirmCustomerAgreementResponse
The confirmation of the terms of agreement when creating the connection/link aggregation group (LAG).
-
#confirm_private_virtual_interface(params = {}) ⇒ Types::ConfirmPrivateVirtualInterfaceResponse
Accepts ownership of a private virtual interface created by another Amazon Web Services account.
-
#confirm_public_virtual_interface(params = {}) ⇒ Types::ConfirmPublicVirtualInterfaceResponse
Accepts ownership of a public virtual interface created by another Amazon Web Services account.
-
#confirm_transit_virtual_interface(params = {}) ⇒ Types::ConfirmTransitVirtualInterfaceResponse
Accepts ownership of a transit virtual interface created by another Amazon Web Services account.
-
#create_bgp_peer(params = {}) ⇒ Types::CreateBGPPeerResponse
Creates a BGP peer on the specified virtual interface.
-
#create_connection(params = {}) ⇒ Types::Connection
Creates a connection between a customer network and a specific Direct Connect location.
-
#create_direct_connect_gateway(params = {}) ⇒ Types::CreateDirectConnectGatewayResult
Creates a Direct Connect gateway, which is an intermediate object that enables you to connect a set of virtual interfaces and virtual private gateways.
-
#create_direct_connect_gateway_association(params = {}) ⇒ Types::CreateDirectConnectGatewayAssociationResult
Creates an association between a Direct Connect gateway and a virtual private gateway.
-
#create_direct_connect_gateway_association_proposal(params = {}) ⇒ Types::CreateDirectConnectGatewayAssociationProposalResult
Creates a proposal to associate the specified virtual private gateway or transit gateway with the specified Direct Connect gateway.
-
#create_interconnect(params = {}) ⇒ Types::Interconnect
Creates an interconnect between an Direct Connect Partner’s network and a specific Direct Connect location.
-
#create_lag(params = {}) ⇒ Types::Lag
Creates a link aggregation group (LAG) with the specified number of bundled physical dedicated connections between the customer network and a specific Direct Connect location.
-
#create_private_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Creates a private virtual interface.
-
#create_public_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Creates a public virtual interface.
-
#create_transit_virtual_interface(params = {}) ⇒ Types::CreateTransitVirtualInterfaceResult
Creates a transit virtual interface.
-
#delete_bgp_peer(params = {}) ⇒ Types::DeleteBGPPeerResponse
Deletes the specified BGP peer on the specified virtual interface with the specified customer address and ASN.
-
#delete_connection(params = {}) ⇒ Types::Connection
Deletes the specified connection.
-
#delete_direct_connect_gateway(params = {}) ⇒ Types::DeleteDirectConnectGatewayResult
Deletes the specified Direct Connect gateway.
-
#delete_direct_connect_gateway_association(params = {}) ⇒ Types::DeleteDirectConnectGatewayAssociationResult
Deletes the association between the specified Direct Connect gateway and virtual private gateway.
-
#delete_direct_connect_gateway_association_proposal(params = {}) ⇒ Types::DeleteDirectConnectGatewayAssociationProposalResult
Deletes the association proposal request between the specified Direct Connect gateway and virtual private gateway or transit gateway.
-
#delete_interconnect(params = {}) ⇒ Types::DeleteInterconnectResponse
Deletes the specified interconnect.
-
#delete_lag(params = {}) ⇒ Types::Lag
Deletes the specified link aggregation group (LAG).
-
#delete_virtual_interface(params = {}) ⇒ Types::DeleteVirtualInterfaceResponse
Deletes a virtual interface.
-
#describe_connection_loa(params = {}) ⇒ Types::DescribeConnectionLoaResponse
Deprecated.
-
#describe_connections(params = {}) ⇒ Types::Connections
Displays the specified connection or all connections in this Region.
-
#describe_connections_on_interconnect(params = {}) ⇒ Types::Connections
Deprecated.
-
#describe_customer_metadata(params = {}) ⇒ Types::DescribeCustomerMetadataResponse
Get and view a list of customer agreements, along with their signed status and whether the customer is an NNIPartner, NNIPartnerV2, or a nonPartner.
-
#describe_direct_connect_gateway_association_proposals(params = {}) ⇒ Types::DescribeDirectConnectGatewayAssociationProposalsResult
Describes one or more association proposals for connection between a virtual private gateway or transit gateway and a Direct Connect gateway.
-
#describe_direct_connect_gateway_associations(params = {}) ⇒ Types::DescribeDirectConnectGatewayAssociationsResult
Lists the associations between your Direct Connect gateways and virtual private gateways and transit gateways.
-
#describe_direct_connect_gateway_attachments(params = {}) ⇒ Types::DescribeDirectConnectGatewayAttachmentsResult
Lists the attachments between your Direct Connect gateways and virtual interfaces.
-
#describe_direct_connect_gateways(params = {}) ⇒ Types::DescribeDirectConnectGatewaysResult
Lists all your Direct Connect gateways or only the specified Direct Connect gateway.
-
#describe_hosted_connections(params = {}) ⇒ Types::Connections
Lists the hosted connections that have been provisioned on the specified interconnect or link aggregation group (LAG).
-
#describe_interconnect_loa(params = {}) ⇒ Types::DescribeInterconnectLoaResponse
Deprecated.
-
#describe_interconnects(params = {}) ⇒ Types::Interconnects
Lists the interconnects owned by the Amazon Web Services account or only the specified interconnect.
-
#describe_lags(params = {}) ⇒ Types::Lags
Describes all your link aggregation groups (LAG) or the specified LAG.
-
#describe_loa(params = {}) ⇒ Types::Loa
Gets the LOA-CFA for a connection, interconnect, or link aggregation group (LAG).
-
#describe_locations(params = {}) ⇒ Types::Locations
Lists the Direct Connect locations in the current Amazon Web Services Region.
-
#describe_router_configuration(params = {}) ⇒ Types::DescribeRouterConfigurationResponse
Details about the router.
-
#describe_tags(params = {}) ⇒ Types::DescribeTagsResponse
Describes the tags associated with the specified Direct Connect resources.
-
#describe_virtual_gateways(params = {}) ⇒ Types::VirtualGateways
Lists the virtual private gateways owned by the Amazon Web Services account.
-
#describe_virtual_interfaces(params = {}) ⇒ Types::VirtualInterfaces
Displays all virtual interfaces for an Amazon Web Services account.
-
#disassociate_connection_from_lag(params = {}) ⇒ Types::Connection
Disassociates a connection from a link aggregation group (LAG).
-
#disassociate_mac_sec_key(params = {}) ⇒ Types::DisassociateMacSecKeyResponse
Removes the association between a MAC Security (MACsec) security key and an Direct Connect dedicated connection.
-
#list_virtual_interface_test_history(params = {}) ⇒ Types::ListVirtualInterfaceTestHistoryResponse
Lists the virtual interface failover test history.
-
#start_bgp_failover_test(params = {}) ⇒ Types::StartBgpFailoverTestResponse
Starts the virtual interface failover test that verifies your configuration meets your resiliency requirements by placing the BGP peering session in the DOWN state.
-
#stop_bgp_failover_test(params = {}) ⇒ Types::StopBgpFailoverTestResponse
Stops the virtual interface failover test.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified Direct Connect resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Direct Connect resource.
-
#update_connection(params = {}) ⇒ Types::Connection
Updates the Direct Connect dedicated connection configuration.
-
#update_direct_connect_gateway(params = {}) ⇒ Types::UpdateDirectConnectGatewayResponse
Updates the name of a current Direct Connect gateway.
-
#update_direct_connect_gateway_association(params = {}) ⇒ Types::UpdateDirectConnectGatewayAssociationResult
Updates the specified attributes of the Direct Connect gateway association.
-
#update_lag(params = {}) ⇒ Types::Lag
Updates the attributes of the specified link aggregation group (LAG).
-
#update_virtual_interface_attributes(params = {}) ⇒ Types::VirtualInterface
Updates the specified attributes of the specified virtual private interface.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
423 424 425 |
# File 'lib/aws-sdk-directconnect/client.rb', line 423 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4971 4972 4973 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4971 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4974 4975 4976 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4974 def errors_module Errors end |
Instance Method Details
#accept_direct_connect_gateway_association_proposal(params = {}) ⇒ Types::AcceptDirectConnectGatewayAssociationProposalResult
Accepts a proposal request to attach a virtual private gateway or transit gateway to a Direct Connect gateway.
491 492 493 494 |
# File 'lib/aws-sdk-directconnect/client.rb', line 491 def accept_direct_connect_gateway_association_proposal(params = {}, = {}) req = build_request(:accept_direct_connect_gateway_association_proposal, params) req.send_request() end |
#allocate_connection_on_interconnect(params = {}) ⇒ Types::Connection
Deprecated. Use AllocateHostedConnection instead.
Creates a hosted connection on an interconnect.
Allocates a VLAN number and a specified amount of bandwidth for use by a hosted connection on the specified interconnect.
<note markdown=“1”> Intended for use by Direct Connect Partners only.
</note>
598 599 600 601 |
# File 'lib/aws-sdk-directconnect/client.rb', line 598 def allocate_connection_on_interconnect(params = {}, = {}) req = build_request(:allocate_connection_on_interconnect, params) req.send_request() end |
#allocate_hosted_connection(params = {}) ⇒ Types::Connection
Creates a hosted connection on the specified interconnect or a link aggregation group (LAG) of interconnects.
Allocates a VLAN number and a specified amount of capacity (bandwidth) for use by a hosted connection on the specified interconnect or LAG of interconnects. Amazon Web Services polices the hosted connection for the specified capacity and the Direct Connect Partner must also police the hosted connection for the specified capacity.
<note markdown=“1”> Intended for use by Direct Connect Partners only.
</note>
715 716 717 718 |
# File 'lib/aws-sdk-directconnect/client.rb', line 715 def allocate_hosted_connection(params = {}, = {}) req = build_request(:allocate_hosted_connection, params) req.send_request() end |
#allocate_private_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Provisions a private virtual interface to be owned by the specified Amazon Web Services account.
Virtual interfaces created using this action must be confirmed by the owner using ConfirmPrivateVirtualInterface. Until then, the virtual interface is in the ‘Confirming` state and is not available to handle traffic.
837 838 839 840 |
# File 'lib/aws-sdk-directconnect/client.rb', line 837 def allocate_private_virtual_interface(params = {}, = {}) req = build_request(:allocate_private_virtual_interface, params) req.send_request() end |
#allocate_public_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Provisions a public virtual interface to be owned by the specified Amazon Web Services account.
The owner of a connection calls this function to provision a public virtual interface to be owned by the specified Amazon Web Services account.
Virtual interfaces created using this function must be confirmed by the owner using ConfirmPublicVirtualInterface. Until this step has been completed, the virtual interface is in the ‘confirming` state and is not available to handle traffic.
When creating an IPv6 public virtual interface, omit the Amazon address and customer address. IPv6 addresses are automatically assigned from the Amazon pool of IPv6 addresses; you cannot specify custom IPv6 addresses.
972 973 974 975 |
# File 'lib/aws-sdk-directconnect/client.rb', line 972 def allocate_public_virtual_interface(params = {}, = {}) req = build_request(:allocate_public_virtual_interface, params) req.send_request() end |
#allocate_transit_virtual_interface(params = {}) ⇒ Types::AllocateTransitVirtualInterfaceResult
Provisions a transit virtual interface to be owned by the specified Amazon Web Services account. Use this type of interface to connect a transit gateway to your Direct Connect gateway.
The owner of a connection provisions a transit virtual interface to be owned by the specified Amazon Web Services account.
After you create a transit virtual interface, it must be confirmed by the owner using ConfirmTransitVirtualInterface. Until this step has been completed, the transit virtual interface is in the ‘requested` state and is not available to handle traffic.
1073 1074 1075 1076 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1073 def allocate_transit_virtual_interface(params = {}, = {}) req = build_request(:allocate_transit_virtual_interface, params) req.send_request() end |
#associate_connection_with_lag(params = {}) ⇒ Types::Connection
Associates an existing connection with a link aggregation group (LAG). The connection is interrupted and re-established as a member of the LAG (connectivity to Amazon Web Services is interrupted). The connection must be hosted on the same Direct Connect endpoint as the LAG, and its bandwidth must match the bandwidth for the LAG. You can re-associate a connection that’s currently associated with a different LAG; however, if removing the connection would cause the original LAG to fall below its setting for minimum number of operational connections, the request fails.
Any virtual interfaces that are directly associated with the connection are automatically re-associated with the LAG. If the connection was originally associated with a different LAG, the virtual interfaces remain associated with the original LAG.
For interconnects, any hosted connections are automatically re-associated with the LAG. If the interconnect was originally associated with a different LAG, the hosted connections remain associated with the original LAG.
1171 1172 1173 1174 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1171 def associate_connection_with_lag(params = {}, = {}) req = build_request(:associate_connection_with_lag, params) req.send_request() end |
#associate_hosted_connection(params = {}) ⇒ Types::Connection
Associates a hosted connection and its virtual interfaces with a link aggregation group (LAG) or interconnect. If the target interconnect or LAG has an existing hosted connection with a conflicting VLAN number or IP address, the operation fails. This action temporarily interrupts the hosted connection’s connectivity to Amazon Web Services as it is being migrated.
<note markdown=“1”> Intended for use by Direct Connect Partners only.
</note>
1260 1261 1262 1263 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1260 def associate_hosted_connection(params = {}, = {}) req = build_request(:associate_hosted_connection, params) req.send_request() end |
#associate_mac_sec_key(params = {}) ⇒ Types::AssociateMacSecKeyResponse
Associates a MAC Security (MACsec) Connection Key Name (CKN)/ Connectivity Association Key (CAK) pair with an Direct Connect dedicated connection.
You must supply either the ‘secretARN,` or the CKN/CAK (`ckn` and `cak`) pair in the request.
For information about MAC Security (MACsec) key considerations, see
- MACsec pre-shared CKN/CAK key considerations ][1
-
in the *Direct
Connect User Guide*.
1346 1347 1348 1349 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1346 def associate_mac_sec_key(params = {}, = {}) req = build_request(:associate_mac_sec_key, params) req.send_request() end |
#associate_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Associates a virtual interface with a specified link aggregation group (LAG) or connection. Connectivity to Amazon Web Services is temporarily interrupted as the virtual interface is being migrated. If the target connection or LAG has an associated virtual interface with a conflicting VLAN number or a conflicting IP address, the operation fails.
Virtual interfaces associated with a hosted connection cannot be associated with a LAG; hosted connections must be migrated along with their virtual interfaces using AssociateHostedConnection.
To reassociate a virtual interface to a new connection or LAG, the requester must own either the virtual interface itself or the connection to which the virtual interface is currently associated. Additionally, the requester must own the connection or LAG for the association.
1456 1457 1458 1459 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1456 def associate_virtual_interface(params = {}, = {}) req = build_request(:associate_virtual_interface, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4949 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-directconnect' context[:gem_version] = '1.74.0' Seahorse::Client::Request.new(handlers, context) end |
#confirm_connection(params = {}) ⇒ Types::ConfirmConnectionResponse
Confirms the creation of the specified hosted connection on an interconnect.
Upon creation, the hosted connection is initially in the ‘Ordering` state, and remains in this state until the owner confirms creation of the hosted connection.
1489 1490 1491 1492 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1489 def confirm_connection(params = {}, = {}) req = build_request(:confirm_connection, params) req.send_request() end |
#confirm_customer_agreement(params = {}) ⇒ Types::ConfirmCustomerAgreementResponse
The confirmation of the terms of agreement when creating the connection/link aggregation group (LAG).
1518 1519 1520 1521 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1518 def confirm_customer_agreement(params = {}, = {}) req = build_request(:confirm_customer_agreement, params) req.send_request() end |
#confirm_private_virtual_interface(params = {}) ⇒ Types::ConfirmPrivateVirtualInterfaceResponse
Accepts ownership of a private virtual interface created by another Amazon Web Services account.
After the virtual interface owner makes this call, the virtual interface is created and attached to the specified virtual private gateway or Direct Connect gateway, and is made available to handle traffic.
1560 1561 1562 1563 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1560 def confirm_private_virtual_interface(params = {}, = {}) req = build_request(:confirm_private_virtual_interface, params) req.send_request() end |
#confirm_public_virtual_interface(params = {}) ⇒ Types::ConfirmPublicVirtualInterfaceResponse
Accepts ownership of a public virtual interface created by another Amazon Web Services account.
After the virtual interface owner makes this call, the specified virtual interface is created and made available to handle traffic.
1592 1593 1594 1595 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1592 def confirm_public_virtual_interface(params = {}, = {}) req = build_request(:confirm_public_virtual_interface, params) req.send_request() end |
#confirm_transit_virtual_interface(params = {}) ⇒ Types::ConfirmTransitVirtualInterfaceResponse
Accepts ownership of a transit virtual interface created by another Amazon Web Services account.
After the owner of the transit virtual interface makes this call, the specified transit virtual interface is created and made available to handle traffic.
1629 1630 1631 1632 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1629 def confirm_transit_virtual_interface(params = {}, = {}) req = build_request(:confirm_transit_virtual_interface, params) req.send_request() end |
#create_bgp_peer(params = {}) ⇒ Types::CreateBGPPeerResponse
Creates a BGP peer on the specified virtual interface.
You must create a BGP peer for the corresponding address family (IPv4/IPv6) in order to access Amazon Web Services resources that also use that address family.
If logical redundancy is not supported by the connection, interconnect, or LAG, the BGP peer cannot be in the same address family as an existing BGP peer on the virtual interface.
When creating a IPv6 BGP peer, omit the Amazon address and customer address. IPv6 addresses are automatically assigned from the Amazon pool of IPv6 addresses; you cannot specify custom IPv6 addresses.
If you let Amazon Web Services auto-assign IPv4 addresses, a /30 CIDR will be allocated from 169.254.0.0/16. Amazon Web Services does not recommend this option if you intend to use the customer router peer IP address as the source and destination for traffic. Instead you should use RFC 1918 or other addressing, and specify the address yourself. For more information about RFC 1918 see [ Address Allocation for Private Internets].
For a public virtual interface, the Autonomous System Number (ASN) must be private or already on the allow list for the virtual interface.
1733 1734 1735 1736 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1733 def create_bgp_peer(params = {}, = {}) req = build_request(:create_bgp_peer, params) req.send_request() end |
#create_connection(params = {}) ⇒ Types::Connection
Creates a connection between a customer network and a specific Direct Connect location.
A connection links your internal network to an Direct Connect location over a standard Ethernet fiber-optic cable. One end of the cable is connected to your router, the other to an Direct Connect router.
To find the locations for your Region, use DescribeLocations.
You can automatically add the new connection to a link aggregation group (LAG) by specifying a LAG ID in the request. This ensures that the new connection is allocated on the same Direct Connect endpoint that hosts the specified LAG. If there are no available ports on the endpoint, the request fails and no connection is created.
1861 1862 1863 1864 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1861 def create_connection(params = {}, = {}) req = build_request(:create_connection, params) req.send_request() end |
#create_direct_connect_gateway(params = {}) ⇒ Types::CreateDirectConnectGatewayResult
Creates a Direct Connect gateway, which is an intermediate object that enables you to connect a set of virtual interfaces and virtual private gateways. A Direct Connect gateway is global and visible in any Amazon Web Services Region after it is created. The virtual interfaces and virtual private gateways that are connected through a Direct Connect gateway can be in different Amazon Web Services Regions. This enables you to connect to a VPC in any Region, regardless of the Region in which the virtual interfaces are located, and pass traffic between them.
1909 1910 1911 1912 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1909 def create_direct_connect_gateway(params = {}, = {}) req = build_request(:create_direct_connect_gateway, params) req.send_request() end |
#create_direct_connect_gateway_association(params = {}) ⇒ Types::CreateDirectConnectGatewayAssociationResult
Creates an association between a Direct Connect gateway and a virtual private gateway. The virtual private gateway must be attached to a VPC and must not be associated with another Direct Connect gateway.
1978 1979 1980 1981 |
# File 'lib/aws-sdk-directconnect/client.rb', line 1978 def create_direct_connect_gateway_association(params = {}, = {}) req = build_request(:create_direct_connect_gateway_association, params) req.send_request() end |
#create_direct_connect_gateway_association_proposal(params = {}) ⇒ Types::CreateDirectConnectGatewayAssociationProposalResult
Creates a proposal to associate the specified virtual private gateway or transit gateway with the specified Direct Connect gateway.
You can associate a Direct Connect gateway and virtual private gateway or transit gateway that is owned by any Amazon Web Services account.
2047 2048 2049 2050 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2047 def create_direct_connect_gateway_association_proposal(params = {}, = {}) req = build_request(:create_direct_connect_gateway_association_proposal, params) req.send_request() end |
#create_interconnect(params = {}) ⇒ Types::Interconnect
Creates an interconnect between an Direct Connect Partner’s network and a specific Direct Connect location.
An interconnect is a connection that is capable of hosting other connections. The Direct Connect Partner can use an interconnect to provide Direct Connect hosted connections to customers through their own network services. Like a standard connection, an interconnect links the partner’s network to an Direct Connect location over a standard Ethernet fiber-optic cable. One end is connected to the partner’s router, the other to an Direct Connect router.
You can automatically add the new interconnect to a link aggregation group (LAG) by specifying a LAG ID in the request. This ensures that the new interconnect is allocated on the same Direct Connect endpoint that hosts the specified LAG. If there are no available ports on the endpoint, the request fails and no interconnect is created.
For each end customer, the Direct Connect Partner provisions a connection on their interconnect by calling AllocateHostedConnection. The end customer can then connect to Amazon Web Services resources by creating a virtual interface on their connection, using the VLAN assigned to them by the Direct Connect Partner.
<note markdown=“1”> Intended for use by Direct Connect Partners only.
</note>
2155 2156 2157 2158 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2155 def create_interconnect(params = {}, = {}) req = build_request(:create_interconnect, params) req.send_request() end |
#create_lag(params = {}) ⇒ Types::Lag
Creates a link aggregation group (LAG) with the specified number of bundled physical dedicated connections between the customer network and a specific Direct Connect location. A LAG is a logical interface that uses the Link Aggregation Control Protocol (LACP) to aggregate multiple interfaces, enabling you to treat them as a single interface.
All connections in a LAG must use the same bandwidth (either 1Gbps or 10Gbps) and must terminate at the same Direct Connect endpoint.
You can have up to 10 dedicated connections per LAG. Regardless of this limit, if you request more connections for the LAG than Direct Connect can allocate on a single endpoint, no LAG is created.
You can specify an existing physical dedicated connection or interconnect to include in the LAG (which counts towards the total number of connections). Doing so interrupts the current physical dedicated connection, and re-establishes them as a member of the LAG. The LAG will be created on the same Direct Connect endpoint to which the dedicated connection terminates. Any virtual interfaces associated with the dedicated connection are automatically disassociated and re-associated with the LAG. The connection ID does not change.
If the Amazon Web Services account used to create a LAG is a registered Direct Connect Partner, the LAG is automatically enabled to host sub-connections. For a LAG owned by a partner, any associated virtual interfaces cannot be directly configured.
2337 2338 2339 2340 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2337 def create_lag(params = {}, = {}) req = build_request(:create_lag, params) req.send_request() end |
#create_private_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Creates a private virtual interface. A virtual interface is the VLAN that transports Direct Connect traffic. A private virtual interface can be connected to either a Direct Connect gateway or a Virtual Private Gateway (VGW). Connecting the private virtual interface to a Direct Connect gateway enables the possibility for connecting to multiple VPCs, including VPCs in different Amazon Web Services Regions. Connecting the private virtual interface to a VGW only provides access to a single VPC within the same Region.
Setting the MTU of a virtual interface to 9001 (jumbo frames) can cause an update to the underlying physical connection if it wasn’t updated to support jumbo frames. Updating the connection disrupts network connectivity for all virtual interfaces associated with the connection for up to 30 seconds. To check whether your connection supports jumbo frames, call DescribeConnections. To check whether your virtual interface supports jumbo frames, call DescribeVirtualInterfaces.
2466 2467 2468 2469 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2466 def create_private_virtual_interface(params = {}, = {}) req = build_request(:create_private_virtual_interface, params) req.send_request() end |
#create_public_virtual_interface(params = {}) ⇒ Types::VirtualInterface
Creates a public virtual interface. A virtual interface is the VLAN that transports Direct Connect traffic. A public virtual interface supports sending traffic to public services of Amazon Web Services such as Amazon S3.
When creating an IPv6 public virtual interface (‘addressFamily` is `ipv6`), leave the `customer` and `amazon` address fields blank to use auto-assigned IPv6 space. Custom IPv6 addresses are not supported.
2587 2588 2589 2590 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2587 def create_public_virtual_interface(params = {}, = {}) req = build_request(:create_public_virtual_interface, params) req.send_request() end |
#create_transit_virtual_interface(params = {}) ⇒ Types::CreateTransitVirtualInterfaceResult
Creates a transit virtual interface. A transit virtual interface should be used to access one or more transit gateways associated with Direct Connect gateways. A transit virtual interface enables the connection of multiple VPCs attached to a transit gateway to a Direct Connect gateway.
If you associate your transit gateway with one or more Direct Connect gateways, the Autonomous System Number (ASN) used by the transit gateway and the Direct Connect gateway must be different. For example, if you use the default ASN 64512 for both your the transit gateway and Direct Connect gateway, the association request fails.
A jumbo MTU value must be either 1500 or 8500. No other values will be accepted. Setting the MTU of a virtual interface to 8500 (jumbo frames) can cause an update to the underlying physical connection if it wasn’t updated to support jumbo frames. Updating the connection disrupts network connectivity for all virtual interfaces associated with the connection for up to 30 seconds. To check whether your connection supports jumbo frames, call DescribeConnections. To check whether your virtual interface supports jumbo frames, call DescribeVirtualInterfaces.
2694 2695 2696 2697 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2694 def create_transit_virtual_interface(params = {}, = {}) req = build_request(:create_transit_virtual_interface, params) req.send_request() end |
#delete_bgp_peer(params = {}) ⇒ Types::DeleteBGPPeerResponse
Deletes the specified BGP peer on the specified virtual interface with the specified customer address and ASN.
You cannot delete the last BGP peer from a virtual interface.
2776 2777 2778 2779 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2776 def delete_bgp_peer(params = {}, = {}) req = build_request(:delete_bgp_peer, params) req.send_request() end |
#delete_connection(params = {}) ⇒ Types::Connection
Deletes the specified connection.
Deleting a connection only stops the Direct Connect port hour and data transfer charges. If you are partnering with any third parties to connect with the Direct Connect location, you must cancel your service with them separately.
2857 2858 2859 2860 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2857 def delete_connection(params = {}, = {}) req = build_request(:delete_connection, params) req.send_request() end |
#delete_direct_connect_gateway(params = {}) ⇒ Types::DeleteDirectConnectGatewayResult
Deletes the specified Direct Connect gateway. You must first delete all virtual interfaces that are attached to the Direct Connect gateway and disassociate all virtual private gateways associated with the Direct Connect gateway.
2893 2894 2895 2896 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2893 def delete_direct_connect_gateway(params = {}, = {}) req = build_request(:delete_direct_connect_gateway, params) req.send_request() end |
#delete_direct_connect_gateway_association(params = {}) ⇒ Types::DeleteDirectConnectGatewayAssociationResult
Deletes the association between the specified Direct Connect gateway and virtual private gateway.
We recommend that you specify the ‘associationID` to delete the association. Alternatively, if you own virtual gateway and a Direct Connect gateway association, you can specify the `virtualGatewayId` and `directConnectGatewayId` to delete an association.
2948 2949 2950 2951 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2948 def delete_direct_connect_gateway_association(params = {}, = {}) req = build_request(:delete_direct_connect_gateway_association, params) req.send_request() end |
#delete_direct_connect_gateway_association_proposal(params = {}) ⇒ Types::DeleteDirectConnectGatewayAssociationProposalResult
Deletes the association proposal request between the specified Direct Connect gateway and virtual private gateway or transit gateway.
2988 2989 2990 2991 |
# File 'lib/aws-sdk-directconnect/client.rb', line 2988 def delete_direct_connect_gateway_association_proposal(params = {}, = {}) req = build_request(:delete_direct_connect_gateway_association_proposal, params) req.send_request() end |
#delete_interconnect(params = {}) ⇒ Types::DeleteInterconnectResponse
Deletes the specified interconnect.
<note markdown=“1”> Intended for use by Direct Connect Partners only.
</note>
3020 3021 3022 3023 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3020 def delete_interconnect(params = {}, = {}) req = build_request(:delete_interconnect, params) req.send_request() end |
#delete_lag(params = {}) ⇒ Types::Lag
Deletes the specified link aggregation group (LAG). You cannot delete a LAG if it has active virtual interfaces or hosted connections.
3123 3124 3125 3126 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3123 def delete_lag(params = {}, = {}) req = build_request(:delete_lag, params) req.send_request() end |
#delete_virtual_interface(params = {}) ⇒ Types::DeleteVirtualInterfaceResponse
Deletes a virtual interface.
3151 3152 3153 3154 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3151 def delete_virtual_interface(params = {}, = {}) req = build_request(:delete_virtual_interface, params) req.send_request() end |
#describe_connection_loa(params = {}) ⇒ Types::DescribeConnectionLoaResponse
Deprecated. Use DescribeLoa instead.
Gets the LOA-CFA for a connection.
The Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a document that your APN partner or service provider uses when establishing your cross connect to Amazon Web Services at the colocation facility. For more information, see [Requesting Cross Connects at Direct Connect Locations] in the *Direct Connect User Guide*.
[1]: docs.aws.amazon.com/directconnect/latest/UserGuide/Colocation.html
3205 3206 3207 3208 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3205 def describe_connection_loa(params = {}, = {}) req = build_request(:describe_connection_loa, params) req.send_request() end |
#describe_connections(params = {}) ⇒ Types::Connections
Displays the specified connection or all connections in this Region.
3261 3262 3263 3264 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3261 def describe_connections(params = {}, = {}) req = build_request(:describe_connections, params) req.send_request() end |
#describe_connections_on_interconnect(params = {}) ⇒ Types::Connections
Deprecated. Use DescribeHostedConnections instead.
Lists the connections that have been provisioned on the specified interconnect.
<note markdown=“1”> Intended for use by Direct Connect Partners only.
</note>
3324 3325 3326 3327 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3324 def describe_connections_on_interconnect(params = {}, = {}) req = build_request(:describe_connections_on_interconnect, params) req.send_request() end |
#describe_customer_metadata(params = {}) ⇒ Types::DescribeCustomerMetadataResponse
Get and view a list of customer agreements, along with their signed status and whether the customer is an NNIPartner, NNIPartnerV2, or a nonPartner.
3349 3350 3351 3352 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3349 def (params = {}, = {}) req = build_request(:describe_customer_metadata, params) req.send_request() end |
#describe_direct_connect_gateway_association_proposals(params = {}) ⇒ Types::DescribeDirectConnectGatewayAssociationProposalsResult
Describes one or more association proposals for connection between a virtual private gateway or transit gateway and a Direct Connect gateway.
3414 3415 3416 3417 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3414 def describe_direct_connect_gateway_association_proposals(params = {}, = {}) req = build_request(:describe_direct_connect_gateway_association_proposals, params) req.send_request() end |
#describe_direct_connect_gateway_associations(params = {}) ⇒ Types::DescribeDirectConnectGatewayAssociationsResult
Lists the associations between your Direct Connect gateways and virtual private gateways and transit gateways. You must specify one of the following:
-
A Direct Connect gateway
The response contains all virtual private gateways and transit gateways associated with the Direct Connect gateway.
-
A virtual private gateway
The response contains the Direct Connect gateway.
-
A transit gateway
The response contains the Direct Connect gateway.
-
A Direct Connect gateway and a virtual private gateway
The response contains the association between the Direct Connect gateway and virtual private gateway.
-
A Direct Connect gateway and a transit gateway
The response contains the association between the Direct Connect gateway and transit gateway.
3508 3509 3510 3511 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3508 def describe_direct_connect_gateway_associations(params = {}, = {}) req = build_request(:describe_direct_connect_gateway_associations, params) req.send_request() end |
#describe_direct_connect_gateway_attachments(params = {}) ⇒ Types::DescribeDirectConnectGatewayAttachmentsResult
Lists the attachments between your Direct Connect gateways and virtual interfaces. You must specify a Direct Connect gateway, a virtual interface, or both. If you specify a Direct Connect gateway, the response contains all virtual interfaces attached to the Direct Connect gateway. If you specify a virtual interface, the response contains all Direct Connect gateways attached to the virtual interface. If you specify both, the response contains the attachment between the Direct Connect gateway and the virtual interface.
3569 3570 3571 3572 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3569 def (params = {}, = {}) req = build_request(:describe_direct_connect_gateway_attachments, params) req.send_request() end |
#describe_direct_connect_gateways(params = {}) ⇒ Types::DescribeDirectConnectGatewaysResult
Lists all your Direct Connect gateways or only the specified Direct Connect gateway. Deleted Direct Connect gateways are not returned.
3619 3620 3621 3622 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3619 def describe_direct_connect_gateways(params = {}, = {}) req = build_request(:describe_direct_connect_gateways, params) req.send_request() end |
#describe_hosted_connections(params = {}) ⇒ Types::Connections
Lists the hosted connections that have been provisioned on the specified interconnect or link aggregation group (LAG).
<note markdown=“1”> Intended for use by Direct Connect Partners only.
</note>
3680 3681 3682 3683 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3680 def describe_hosted_connections(params = {}, = {}) req = build_request(:describe_hosted_connections, params) req.send_request() end |
#describe_interconnect_loa(params = {}) ⇒ Types::DescribeInterconnectLoaResponse
Deprecated. Use DescribeLoa instead.
Gets the LOA-CFA for the specified interconnect.
The Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a document that is used when establishing your cross connect to Amazon Web Services at the colocation facility. For more information, see [Requesting Cross Connects at Direct Connect Locations] in the *Direct Connect User Guide*.
[1]: docs.aws.amazon.com/directconnect/latest/UserGuide/Colocation.html
3733 3734 3735 3736 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3733 def describe_interconnect_loa(params = {}, = {}) req = build_request(:describe_interconnect_loa, params) req.send_request() end |
#describe_interconnects(params = {}) ⇒ Types::Interconnects
Lists the interconnects owned by the Amazon Web Services account or only the specified interconnect.
3779 3780 3781 3782 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3779 def describe_interconnects(params = {}, = {}) req = build_request(:describe_interconnects, params) req.send_request() end |
#describe_lags(params = {}) ⇒ Types::Lags
Describes all your link aggregation groups (LAG) or the specified LAG.
3862 3863 3864 3865 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3862 def describe_lags(params = {}, = {}) req = build_request(:describe_lags, params) req.send_request() end |
#describe_loa(params = {}) ⇒ Types::Loa
Gets the LOA-CFA for a connection, interconnect, or link aggregation group (LAG).
The Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a document that is used when establishing your cross connect to Amazon Web Services at the colocation facility. For more information, see [Requesting Cross Connects at Direct Connect Locations] in the *Direct Connect User Guide*.
[1]: docs.aws.amazon.com/directconnect/latest/UserGuide/Colocation.html
3915 3916 3917 3918 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3915 def describe_loa(params = {}, = {}) req = build_request(:describe_loa, params) req.send_request() end |
#describe_locations(params = {}) ⇒ Types::Locations
Lists the Direct Connect locations in the current Amazon Web Services Region. These are the locations that can be selected when calling CreateConnection or CreateInterconnect.
3945 3946 3947 3948 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3945 def describe_locations(params = {}, = {}) req = build_request(:describe_locations, params) req.send_request() end |
#describe_router_configuration(params = {}) ⇒ Types::DescribeRouterConfigurationResponse
Details about the router.
3990 3991 3992 3993 |
# File 'lib/aws-sdk-directconnect/client.rb', line 3990 def describe_router_configuration(params = {}, = {}) req = build_request(:describe_router_configuration, params) req.send_request() end |
#describe_tags(params = {}) ⇒ Types::DescribeTagsResponse
Describes the tags associated with the specified Direct Connect resources.
4023 4024 4025 4026 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4023 def (params = {}, = {}) req = build_request(:describe_tags, params) req.send_request() end |
#describe_virtual_gateways(params = {}) ⇒ Types::VirtualGateways
Lists the virtual private gateways owned by the Amazon Web Services account.
You can create one or more Direct Connect private virtual interfaces linked to a virtual private gateway.
4048 4049 4050 4051 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4048 def describe_virtual_gateways(params = {}, = {}) req = build_request(:describe_virtual_gateways, params) req.send_request() end |
#describe_virtual_interfaces(params = {}) ⇒ Types::VirtualInterfaces
Displays all virtual interfaces for an Amazon Web Services account. Virtual interfaces deleted fewer than 15 minutes before you make the request are also returned. If you specify a connection ID, only the virtual interfaces associated with the connection are returned. If you specify a virtual interface ID, then only a single virtual interface is returned.
A virtual interface (VLAN) transmits the traffic between the Direct Connect location and the customer network.
4127 4128 4129 4130 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4127 def describe_virtual_interfaces(params = {}, = {}) req = build_request(:describe_virtual_interfaces, params) req.send_request() end |
#disassociate_connection_from_lag(params = {}) ⇒ Types::Connection
Disassociates a connection from a link aggregation group (LAG). The connection is interrupted and re-established as a standalone connection (the connection is not deleted; to delete the connection, use the DeleteConnection request). If the LAG has associated virtual interfaces or hosted connections, they remain associated with the LAG. A disassociated connection owned by an Direct Connect Partner is automatically converted to an interconnect.
If disassociating the connection would cause the LAG to fall below its setting for minimum number of operational connections, the request fails, except when it’s the last member of the LAG. If all connections are disassociated, the LAG continues to exist as an empty LAG with no physical connections.
4219 4220 4221 4222 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4219 def disassociate_connection_from_lag(params = {}, = {}) req = build_request(:disassociate_connection_from_lag, params) req.send_request() end |
#disassociate_mac_sec_key(params = {}) ⇒ Types::DisassociateMacSecKeyResponse
Removes the association between a MAC Security (MACsec) security key and an Direct Connect dedicated connection.
4266 4267 4268 4269 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4266 def disassociate_mac_sec_key(params = {}, = {}) req = build_request(:disassociate_mac_sec_key, params) req.send_request() end |
#list_virtual_interface_test_history(params = {}) ⇒ Types::ListVirtualInterfaceTestHistoryResponse
Lists the virtual interface failover test history.
4331 4332 4333 4334 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4331 def list_virtual_interface_test_history(params = {}, = {}) req = build_request(:list_virtual_interface_test_history, params) req.send_request() end |
#start_bgp_failover_test(params = {}) ⇒ Types::StartBgpFailoverTestResponse
Starts the virtual interface failover test that verifies your configuration meets your resiliency requirements by placing the BGP peering session in the DOWN state. You can then send traffic to verify that there are no outages.
You can run the test on public, private, transit, and hosted virtual interfaces.
You can use [ListVirtualInterfaceTestHistory] to view the virtual interface test history.
If you need to stop the test before the test interval completes, use [StopBgpFailoverTest].
[1]: docs.aws.amazon.com/directconnect/latest/APIReference/API_ListVirtualInterfaceTestHistory.html [2]: docs.aws.amazon.com/directconnect/latest/APIReference/API_StopBgpFailoverTest.html
4397 4398 4399 4400 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4397 def start_bgp_failover_test(params = {}, = {}) req = build_request(:start_bgp_failover_test, params) req.send_request() end |
#stop_bgp_failover_test(params = {}) ⇒ Types::StopBgpFailoverTestResponse
Stops the virtual interface failover test.
4433 4434 4435 4436 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4433 def stop_bgp_failover_test(params = {}, = {}) req = build_request(:stop_bgp_failover_test, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified Direct Connect resource. Each resource can have a maximum of 50 tags.
Each tag consists of a key and an optional value. If a tag with the same key is already associated with the resource, this action updates its value.
4469 4470 4471 4472 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4469 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Direct Connect resource.
4495 4496 4497 4498 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4495 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_connection(params = {}) ⇒ Types::Connection
Updates the Direct Connect dedicated connection configuration.
You can update the following parameters for a connection:
-
The connection name
-
The connection’s MAC Security (MACsec) encryption mode.
4590 4591 4592 4593 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4590 def update_connection(params = {}, = {}) req = build_request(:update_connection, params) req.send_request() end |
#update_direct_connect_gateway(params = {}) ⇒ Types::UpdateDirectConnectGatewayResponse
Updates the name of a current Direct Connect gateway.
4627 4628 4629 4630 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4627 def update_direct_connect_gateway(params = {}, = {}) req = build_request(:update_direct_connect_gateway, params) req.send_request() end |
#update_direct_connect_gateway_association(params = {}) ⇒ Types::UpdateDirectConnectGatewayAssociationResult
Updates the specified attributes of the Direct Connect gateway association.
Add or remove prefixes from the association.
4688 4689 4690 4691 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4688 def update_direct_connect_gateway_association(params = {}, = {}) req = build_request(:update_direct_connect_gateway_association, params) req.send_request() end |
#update_lag(params = {}) ⇒ Types::Lag
Updates the attributes of the specified link aggregation group (LAG).
You can update the following LAG attributes:
-
The name of the LAG.
-
The value for the minimum number of connections that must be operational for the LAG itself to be operational.
-
The LAG’s MACsec encryption mode.
Amazon Web Services assigns this value to each connection which is part of the LAG.
-
The tags
<note markdown=“1”> If you adjust the threshold value for the minimum number of operational connections, ensure that the new value does not cause the LAG to fall below the threshold and become non-operational.
</note>
4826 4827 4828 4829 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4826 def update_lag(params = {}, = {}) req = build_request(:update_lag, params) req.send_request() end |
#update_virtual_interface_attributes(params = {}) ⇒ Types::VirtualInterface
Updates the specified attributes of the specified virtual private interface.
Setting the MTU of a virtual interface to 9001 (jumbo frames) can cause an update to the underlying physical connection if it wasn’t updated to support jumbo frames. Updating the connection disrupts network connectivity for all virtual interfaces associated with the connection for up to 30 seconds. To check whether your connection supports jumbo frames, call DescribeConnections. To check whether your virtual interface supports jumbo frames, call DescribeVirtualInterfaces.
4940 4941 4942 4943 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4940 def update_virtual_interface_attributes(params = {}, = {}) req = build_request(:update_virtual_interface_attributes, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4964 4965 4966 |
# File 'lib/aws-sdk-directconnect/client.rb', line 4964 def waiter_names [] end |