Class: Aws::DirectConnect::Types::AllocateConnectionOnInterconnectRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::AllocateConnectionOnInterconnectRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass AllocateConnectionOnInterconnectRequest data as a hash:
{
bandwidth: "Bandwidth", # required
connection_name: "ConnectionName", # required
owner_account: "OwnerAccount", # required
interconnect_id: "InterconnectId", # required
vlan: 1, # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth ⇒ String
The bandwidth of the connection.
-
#connection_name ⇒ String
The name of the provisioned connection.
-
#interconnect_id ⇒ String
The ID of the interconnect on which the connection will be provisioned.
-
#owner_account ⇒ String
The ID of the Amazon Web Services account of the customer for whom the connection will be provisioned.
-
#vlan ⇒ Integer
The dedicated VLAN provisioned to the connection.
Instance Attribute Details
#bandwidth ⇒ String
The bandwidth of the connection. The possible values are 50Mbps, 100Mbps, 200Mbps, 300Mbps, 400Mbps, 500Mbps, 1Gbps, 2Gbps, 5Gbps, and 10Gbps. Note that only those Direct Connect Partners who have met specific requirements are allowed to create a 1Gbps, 2Gbps, 5Gbps or 10Gbps hosted connection.
115 116 117 118 119 120 121 122 123 |
# File 'lib/aws-sdk-directconnect/types.rb', line 115 class AllocateConnectionOnInterconnectRequest < Struct.new( :bandwidth, :connection_name, :owner_account, :interconnect_id, :vlan) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the provisioned connection.
115 116 117 118 119 120 121 122 123 |
# File 'lib/aws-sdk-directconnect/types.rb', line 115 class AllocateConnectionOnInterconnectRequest < Struct.new( :bandwidth, :connection_name, :owner_account, :interconnect_id, :vlan) SENSITIVE = [] include Aws::Structure end |
#interconnect_id ⇒ String
The ID of the interconnect on which the connection will be provisioned.
115 116 117 118 119 120 121 122 123 |
# File 'lib/aws-sdk-directconnect/types.rb', line 115 class AllocateConnectionOnInterconnectRequest < Struct.new( :bandwidth, :connection_name, :owner_account, :interconnect_id, :vlan) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The ID of the Amazon Web Services account of the customer for whom the connection will be provisioned.
115 116 117 118 119 120 121 122 123 |
# File 'lib/aws-sdk-directconnect/types.rb', line 115 class AllocateConnectionOnInterconnectRequest < Struct.new( :bandwidth, :connection_name, :owner_account, :interconnect_id, :vlan) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The dedicated VLAN provisioned to the connection.
115 116 117 118 119 120 121 122 123 |
# File 'lib/aws-sdk-directconnect/types.rb', line 115 class AllocateConnectionOnInterconnectRequest < Struct.new( :bandwidth, :connection_name, :owner_account, :interconnect_id, :vlan) SENSITIVE = [] include Aws::Structure end |