Class: Aws::DirectConnect::Types::AllocateHostedConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::AllocateHostedConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass AllocateHostedConnectionRequest data as a hash:
{
connection_id: "ConnectionId", # required
owner_account: "OwnerAccount", # required
bandwidth: "Bandwidth", # required
connection_name: "ConnectionName", # required
vlan: 1, # required
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth ⇒ String
The bandwidth of the connection.
-
#connection_id ⇒ String
The ID of the interconnect or LAG.
-
#connection_name ⇒ String
The name of the hosted connection.
-
#owner_account ⇒ String
The ID of the Amazon Web Services account ID of the customer for the connection.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the connection.
-
#vlan ⇒ Integer
The dedicated VLAN provisioned to the hosted connection.
Instance Attribute Details
#bandwidth ⇒ String
The bandwidth of the connection. The possible values are 50Mbps, 100Mbps, 200Mbps, 300Mbps, 400Mbps, 500Mbps, 1Gbps, 2Gbps, 5Gbps, and 10Gbps. Note that only those Direct Connect Partners who have met specific requirements are allowed to create a 1Gbps, 2Gbps, 5Gbps or 10Gbps hosted connection.
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/aws-sdk-directconnect/types.rb', line 173 class AllocateHostedConnectionRequest < Struct.new( :connection_id, :owner_account, :bandwidth, :connection_name, :vlan, :tags) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of the interconnect or LAG.
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/aws-sdk-directconnect/types.rb', line 173 class AllocateHostedConnectionRequest < Struct.new( :connection_id, :owner_account, :bandwidth, :connection_name, :vlan, :tags) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the hosted connection.
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/aws-sdk-directconnect/types.rb', line 173 class AllocateHostedConnectionRequest < Struct.new( :connection_id, :owner_account, :bandwidth, :connection_name, :vlan, :tags) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The ID of the Amazon Web Services account ID of the customer for the connection.
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/aws-sdk-directconnect/types.rb', line 173 class AllocateHostedConnectionRequest < Struct.new( :connection_id, :owner_account, :bandwidth, :connection_name, :vlan, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the connection.
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/aws-sdk-directconnect/types.rb', line 173 class AllocateHostedConnectionRequest < Struct.new( :connection_id, :owner_account, :bandwidth, :connection_name, :vlan, :tags) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The dedicated VLAN provisioned to the hosted connection.
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/aws-sdk-directconnect/types.rb', line 173 class AllocateHostedConnectionRequest < Struct.new( :connection_id, :owner_account, :bandwidth, :connection_name, :vlan, :tags) SENSITIVE = [] include Aws::Structure end |