Class: Aws::DirectConnect::Types::AllocatePublicVirtualInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::AllocatePublicVirtualInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Note:
When making an API call, you may pass AllocatePublicVirtualInterfaceRequest data as a hash:
{
connection_id: "ConnectionId", # required
owner_account: "OwnerAccount", # required
new_public_virtual_interface_allocation: { # required
virtual_interface_name: "VirtualInterfaceName", # required
vlan: 1, # required
asn: 1, # required
auth_key: "BGPAuthKey",
amazon_address: "AmazonAddress",
customer_address: "CustomerAddress",
address_family: "ipv4", # accepts ipv4, ipv6
route_filter_prefixes: [
{
cidr: "CIDR",
},
],
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_id ⇒ String
The ID of the connection on which the public virtual interface is provisioned.
-
#new_public_virtual_interface_allocation ⇒ Types::NewPublicVirtualInterfaceAllocation
Information about the public virtual interface.
-
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the public virtual interface.
Instance Attribute Details
#connection_id ⇒ String
The ID of the connection on which the public virtual interface is provisioned.
276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-directconnect/types.rb', line 276 class AllocatePublicVirtualInterfaceRequest < Struct.new( :connection_id, :owner_account, :new_public_virtual_interface_allocation) SENSITIVE = [] include Aws::Structure end |
#new_public_virtual_interface_allocation ⇒ Types::NewPublicVirtualInterfaceAllocation
Information about the public virtual interface.
276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-directconnect/types.rb', line 276 class AllocatePublicVirtualInterfaceRequest < Struct.new( :connection_id, :owner_account, :new_public_virtual_interface_allocation) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the public virtual interface.
276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-directconnect/types.rb', line 276 class AllocatePublicVirtualInterfaceRequest < Struct.new( :connection_id, :owner_account, :new_public_virtual_interface_allocation) SENSITIVE = [] include Aws::Structure end |