Class: Aws::DirectConnect::Types::BGPPeer
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::BGPPeer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a BGP peer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#asn ⇒ Integer
The autonomous system number (ASN).
-
#asn_long ⇒ Integer
The long ASN for the BGP peer.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#aws_device_v2 ⇒ String
The Direct Connect endpoint that terminates the BGP peer.
-
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection.
-
#bgp_peer_id ⇒ String
The ID of the BGP peer.
-
#bgp_peer_state ⇒ String
The state of the BGP peer.
-
#bgp_status ⇒ String
The status of the BGP peer.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system number (ASN). The valid range is from 1 to 2147483646 for Border Gateway Protocol (BGP) configuration. If you provide a number greater than the maximum, an error is returned. Use ‘asnLong` instead.
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
-
If you enter a 4-byte ASN for the ‘asn` parameter, the API returns an error.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#asn_long ⇒ Integer
The long ASN for the BGP peer. The valid range is from 1 to 4294967294 for BGP configuration.
Note the following limitations when using ‘asnLong`:
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
‘asnLong` accepts any valid ASN value, regardless if it’s 2-byte or 4-byte.
-
When using a 4-byte ‘asnLong`, the API response returns `0` for the legacy `asn` attribute since 4-byte ASN values exceed the maximum supported value of 2,147,483,647.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#aws_device_v2 ⇒ String
The Direct Connect endpoint that terminates the BGP peer.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#bgp_peer_id ⇒ String
The ID of the BGP peer.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#bgp_peer_state ⇒ String
The state of the BGP peer. The following are the possible values:
-
‘verifying`: The BGP peering addresses or ASN require validation before the BGP peer can be created. This state applies only to public virtual interfaces.
-
‘pending`: The BGP peer is created, and remains in this state until it is ready to be established.
-
‘available`: The BGP peer is ready to be established.
-
‘deleting`: The BGP peer is being deleted.
-
‘deleted`: The BGP peer is deleted and cannot be established.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#bgp_status ⇒ String
The status of the BGP peer. The following are the possible values:
-
‘up`: The BGP peer is established. This state does not indicate the state of the routing function. Ensure that you are receiving routes over the BGP session.
-
‘down`: The BGP peer is down.
-
‘unknown`: The BGP peer status is not available.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-directconnect/types.rb', line 512 class BGPPeer < Struct.new( :bgp_peer_id, :asn, :asn_long, :auth_key, :address_family, :amazon_address, :customer_address, :bgp_peer_state, :bgp_status, :aws_device_v2, :aws_logical_device_id) SENSITIVE = [] include Aws::Structure end |