Class: Aws::DirectConnect::Types::ConfirmConnectionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::ConfirmConnectionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_state ⇒ String
The state of the connection.
Instance Attribute Details
#connection_state ⇒ String
The state of the connection. The following are the possible values:
-
ordering: The initial state of a hosted connection provisioned on an interconnect. The connection stays in the ordering state until the owner of the hosted connection confirms or declines the connection order. -
requested: The initial state of a standard connection. The connection stays in the requested state until the Letter of Authorization (LOA) is sent to the customer. -
pending: The connection has been approved and is being initialized. -
available: The network link is up and the connection is ready for use. -
down: The network link is down. -
deleting: The connection is being deleted. -
deleted: The connection has been deleted. -
rejected: A hosted connection in theorderingstate enters therejectedstate if it is deleted by the customer. -
unknown: The state of the connection is not available.
562 563 564 565 566 |
# File 'lib/aws-sdk-directconnect/types.rb', line 562 class ConfirmConnectionResponse < Struct.new( :connection_state) SENSITIVE = [] include Aws::Structure end |