Class: Aws::DirectConnect::Types::Connection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Information about an Direct Connect connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_deviceString

The Direct Connect endpoint on which the physical connection terminates.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#aws_device_v2String

The Direct Connect endpoint that terminates the physical connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#aws_logical_device_idString

The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#bandwidthString

The bandwidth of the connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#billing_modeString

The billing mode of the connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#connection_idString

The ID of the connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

The name of the connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#connection_stateString

The state of the connection. The following are the possible values:

  • ordering: The initial state of a hosted connection provisioned on an interconnect. The connection stays in the ordering state until the owner of the hosted connection confirms or declines the connection order.

  • requested: The initial state of a standard connection. The connection stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.

  • pending: The connection has been approved and is being initialized.

  • available: The network link is up and the connection is ready for use.

  • down: The network link is down.

  • deleting: The connection is being deleted.

  • deleted: The connection has been deleted.

  • rejected: A hosted connection in the ordering state enters the rejected state if it is deleted by the customer.

  • unknown: The state of the connection is not available.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_modeString

The MAC Security (MACsec) connection encryption mode.

The valid values are no_encrypt, should_encrypt, and must_encrypt.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#has_logical_redundancyString

Indicates whether the connection supports a secondary BGP peer in the same address family (IPv4/IPv6).

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#jumbo_frame_capableBoolean

Indicates whether jumbo frames are supported.

Returns:

  • (Boolean)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#lag_idString

The ID of the LAG.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#loa_issue_timeTime

The time of the most recent call to DescribeLoa for this connection.

Returns:

  • (Time)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The location of the connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#mac_sec_capableBoolean

Indicates whether the connection supports MAC Security (MACsec).

Returns:

  • (Boolean)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#mac_sec_keysArray<Types::MacSecKey>

The MAC Security (MACsec) security keys associated with the connection.

Returns:



1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#owner_accountString

The ID of the Amazon Web Services account that owns the connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#partner_interconnect_mac_sec_capableBoolean

Indicates whether the interconnect hosting this connection supports MAC Security (MACsec).

Returns:

  • (Boolean)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#partner_nameString

The name of the Direct Connect service provider associated with the connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#port_encryption_statusString

The MAC Security (MACsec) port link status of the connection.

The valid values are Encryption Up, which means that there is an active Connection Key Name, or Encryption Down.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#prefix_pool_size_ipv_4Integer

The total number of inbound IPv4 route prefixes you can allocate across the virtual interfaces on the connection. Not applicable to hosted connections or interconnects.

Returns:

  • (Integer)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#prefix_pool_size_ipv_6Integer

The total number of inbound IPv6 route prefixes you can allocate across the virtual interfaces on the connection. Not applicable to hosted connections or interconnects.

Returns:

  • (Integer)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#prefix_pool_unallocated_count_ipv_4Integer

The number of inbound IPv4 route prefixes in the connection prefix pool not yet allocated to a virtual interface. Not applicable to hosted connections or interconnects.

Returns:

  • (Integer)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#prefix_pool_unallocated_count_ipv_6Integer

The number of inbound IPv6 route prefixes in the connection prefix pool not yet allocated to a virtual interface. Not applicable to hosted connections or interconnects.

Returns:

  • (Integer)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The name of the service provider associated with the connection.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#rate_limiter_statusTypes::RateLimiterStatus

The rate limiter status for the connection, including how many rate limiters are in use and the maximum allowed.



1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region where the connection is located.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the connection.

Returns:



1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#vlanInteger

The ID of the VLAN.

Returns:

  • (Integer)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/aws-sdk-directconnect/types.rb', line 1049

class Connection < Struct.new(
  :owner_account,
  :connection_id,
  :connection_name,
  :connection_state,
  :region,
  :location,
  :bandwidth,
  :vlan,
  :partner_name,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status,
  :partner_interconnect_mac_sec_capable,
  :prefix_pool_size_ipv_4,
  :prefix_pool_size_ipv_6,
  :prefix_pool_unallocated_count_ipv_4,
  :prefix_pool_unallocated_count_ipv_6,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end