Class: Aws::DirectConnect::Types::CreateConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::CreateConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth ⇒ String
The bandwidth of the connection.
-
#billing_mode ⇒ String
The billing mode for the connection.
-
#connection_name ⇒ String
The name of the connection.
-
#lag_id ⇒ String
The ID of the LAG.
-
#location ⇒ String
The location of the connection.
-
#provider_name ⇒ String
The name of the service provider associated with the requested connection.
-
#request_mac_sec ⇒ Boolean
Indicates whether you want the connection to support MAC Security (MACsec).
-
#tags ⇒ Array<Types::Tag>
The tags to associate with the lag.
Instance Attribute Details
#bandwidth ⇒ String
The bandwidth of the connection.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1174 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#billing_mode ⇒ String
The billing mode for the connection.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1174 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the connection.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1174 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#lag_id ⇒ String
The ID of the LAG.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1174 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the connection.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1174 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the requested connection.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1174 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#request_mac_sec ⇒ Boolean
Indicates whether you want the connection to support MAC Security (MACsec).
MAC Security (MACsec) is unavailable on hosted connections. For information about MAC Security (MACsec) prerequisites, see MAC Security in Direct Connect in the Direct Connect User Guide.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1174 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to associate with the lag.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1174 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |