Class: Aws::DirectConnect::Types::CreateDirectConnectGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::CreateDirectConnectGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_side_asn ⇒ Integer
The autonomous system number (ASN) for Border Gateway Protocol (BGP) to be configured on the Amazon side of the connection.
-
#direct_connect_gateway_name ⇒ String
The name of the Direct Connect gateway.
-
#tags ⇒ Array<Types::Tag>
The key-value pair tags associated with the request.
Instance Attribute Details
#amazon_side_asn ⇒ Integer
The autonomous system number (ASN) for Border Gateway Protocol (BGP) to be configured on the Amazon side of the connection. The ASN must be in the private range of 64,512 to 65,534 or 4,200,000,000 to 4,294,967,294. The default is 64512.
1178 1179 1180 1181 1182 1183 1184 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1178 class CreateDirectConnectGatewayRequest < Struct.new( :direct_connect_gateway_name, :tags, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_name ⇒ String
The name of the Direct Connect gateway.
1178 1179 1180 1181 1182 1183 1184 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1178 class CreateDirectConnectGatewayRequest < Struct.new( :direct_connect_gateway_name, :tags, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The key-value pair tags associated with the request.
1178 1179 1180 1181 1182 1183 1184 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1178 class CreateDirectConnectGatewayRequest < Struct.new( :direct_connect_gateway_name, :tags, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |