Class: Aws::DirectConnect::Types::CreateInterconnectRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::CreateInterconnectRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Note:
When making an API call, you may pass CreateInterconnectRequest data as a hash:
{
interconnect_name: "InterconnectName", # required
bandwidth: "Bandwidth", # required
location: "LocationCode", # required
lag_id: "LagId",
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
provider_name: "ProviderName",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth ⇒ String
The port bandwidth, in Gbps.
-
#interconnect_name ⇒ String
The name of the interconnect.
-
#lag_id ⇒ String
The ID of the LAG.
-
#location ⇒ String
The location of the interconnect.
-
#provider_name ⇒ String
The name of the service provider associated with the interconnect.
-
#tags ⇒ Array<Types::Tag>
The tags to associate with the interconnect.
Instance Attribute Details
#bandwidth ⇒ String
The port bandwidth, in Gbps. The possible values are 1 and 10.
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1406 class CreateInterconnectRequest < Struct.new( :interconnect_name, :bandwidth, :location, :lag_id, :tags, :provider_name) SENSITIVE = [] include Aws::Structure end |
#interconnect_name ⇒ String
The name of the interconnect.
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1406 class CreateInterconnectRequest < Struct.new( :interconnect_name, :bandwidth, :location, :lag_id, :tags, :provider_name) SENSITIVE = [] include Aws::Structure end |
#lag_id ⇒ String
The ID of the LAG.
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1406 class CreateInterconnectRequest < Struct.new( :interconnect_name, :bandwidth, :location, :lag_id, :tags, :provider_name) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the interconnect.
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1406 class CreateInterconnectRequest < Struct.new( :interconnect_name, :bandwidth, :location, :lag_id, :tags, :provider_name) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the interconnect.
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1406 class CreateInterconnectRequest < Struct.new( :interconnect_name, :bandwidth, :location, :lag_id, :tags, :provider_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to associate with the interconnect.
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1406 class CreateInterconnectRequest < Struct.new( :interconnect_name, :bandwidth, :location, :lag_id, :tags, :provider_name) SENSITIVE = [] include Aws::Structure end |