Class: Aws::DirectConnect::Types::CreateLagRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::CreateLagRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_mode ⇒ String
The billing mode for the LAG.
-
#child_connection_tags ⇒ Array<Types::Tag>
The tags to associate with the automtically created LAGs.
-
#connection_id ⇒ String
The ID of an existing dedicated connection to migrate to the LAG.
-
#connections_bandwidth ⇒ String
The bandwidth of the individual physical dedicated connections bundled by the LAG.
-
#lag_name ⇒ String
The name of the LAG.
-
#location ⇒ String
The location for the LAG.
-
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG.
-
#provider_name ⇒ String
The name of the service provider associated with the LAG.
-
#request_mac_sec ⇒ Boolean
Indicates whether the connection will support MAC Security (MACsec).
-
#tags ⇒ Array<Types::Tag>
The tags to associate with the LAG.
Instance Attribute Details
#billing_mode ⇒ String
The billing mode for the LAG.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#child_connection_tags ⇒ Array<Types::Tag>
The tags to associate with the automtically created LAGs.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of an existing dedicated connection to migrate to the LAG.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#connections_bandwidth ⇒ String
The bandwidth of the individual physical dedicated connections bundled by the LAG. The possible values are 1Gbps,10Gbps, 100Gbps, and 400Gbps.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#lag_name ⇒ String
The name of the LAG.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location for the LAG.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG. You can have a maximum of four connections when the port speed is 1Gbps or 10Gbps, or two when the port speed is 100Gbps or 400Gbps.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the LAG.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#request_mac_sec ⇒ Boolean
Indicates whether the connection will support MAC Security (MACsec).
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to associate with the LAG.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1420 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec, :billing_mode) SENSITIVE = [] include Aws::Structure end |