Class: Aws::DirectConnect::Types::DeleteInterconnectResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::DeleteInterconnectResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#interconnect_state ⇒ String
The state of the interconnect.
Instance Attribute Details
#interconnect_state ⇒ String
The state of the interconnect. The following are the possible values:
-
requested: The initial state of an interconnect. The interconnect stays in the requested state until the Letter of Authorization (LOA) is sent to the customer. -
pending: The interconnect is approved, and is being initialized. -
available: The network link is up, and the interconnect is ready for use. -
down: The network link is down. -
deleting: The interconnect is being deleted. -
deleted: The interconnect is deleted. -
unknown: The state of the interconnect is not available.
1575 1576 1577 1578 1579 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1575 class DeleteInterconnectResponse < Struct.new( :interconnect_state) SENSITIVE = [] include Aws::Structure end |