Class: Aws::DirectConnect::Types::DescribeDirectConnectGatewayAssociationProposalsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::DescribeDirectConnectGatewayAssociationProposalsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Note:
When making an API call, you may pass DescribeDirectConnectGatewayAssociationProposalsRequest data as a hash:
{
direct_connect_gateway_id: "DirectConnectGatewayId",
proposal_id: "DirectConnectGatewayAssociationProposalId",
associated_gateway_id: "AssociatedGatewayId",
max_results: 1,
next_token: "PaginationToken",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_gateway_id ⇒ String
The ID of the associated gateway.
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#proposal_id ⇒ String
The ID of the proposal.
Instance Attribute Details
#associated_gateway_id ⇒ String
The ID of the associated gateway.
2124 2125 2126 2127 2128 2129 2130 2131 2132 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2124 class DescribeDirectConnectGatewayAssociationProposalsRequest < Struct.new( :direct_connect_gateway_id, :proposal_id, :associated_gateway_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
2124 2125 2126 2127 2128 2129 2130 2131 2132 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2124 class DescribeDirectConnectGatewayAssociationProposalsRequest < Struct.new( :direct_connect_gateway_id, :proposal_id, :associated_gateway_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned `nextToken` value.
If `MaxResults` is given a value larger than 100, only 100 results are returned.
2124 2125 2126 2127 2128 2129 2130 2131 2132 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2124 class DescribeDirectConnectGatewayAssociationProposalsRequest < Struct.new( :direct_connect_gateway_id, :proposal_id, :associated_gateway_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
2124 2125 2126 2127 2128 2129 2130 2131 2132 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2124 class DescribeDirectConnectGatewayAssociationProposalsRequest < Struct.new( :direct_connect_gateway_id, :proposal_id, :associated_gateway_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#proposal_id ⇒ String
The ID of the proposal.
2124 2125 2126 2127 2128 2129 2130 2131 2132 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2124 class DescribeDirectConnectGatewayAssociationProposalsRequest < Struct.new( :direct_connect_gateway_id, :proposal_id, :associated_gateway_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |