Class: Aws::DirectConnect::Types::DescribeDirectConnectGatewayAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::DescribeDirectConnectGatewayAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass DescribeDirectConnectGatewayAssociationsRequest data as a hash:
{
association_id: "DirectConnectGatewayAssociationId",
associated_gateway_id: "AssociatedGatewayId",
direct_connect_gateway_id: "DirectConnectGatewayId",
max_results: 1,
next_token: "PaginationToken",
virtual_gateway_id: "VirtualGatewayId",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_gateway_id ⇒ String
The ID of the associated gateway.
-
#association_id ⇒ String
The ID of the Direct Connect gateway association.
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token provided in the previous call to retrieve the next page.
-
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway or transit gateway.
Instance Attribute Details
#associated_gateway_id ⇒ String
The ID of the associated gateway.
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2195 class DescribeDirectConnectGatewayAssociationsRequest < Struct.new( :association_id, :associated_gateway_id, :direct_connect_gateway_id, :max_results, :next_token, :virtual_gateway_id) SENSITIVE = [] include Aws::Structure end |
#association_id ⇒ String
The ID of the Direct Connect gateway association.
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2195 class DescribeDirectConnectGatewayAssociationsRequest < Struct.new( :association_id, :associated_gateway_id, :direct_connect_gateway_id, :max_results, :next_token, :virtual_gateway_id) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2195 class DescribeDirectConnectGatewayAssociationsRequest < Struct.new( :association_id, :associated_gateway_id, :direct_connect_gateway_id, :max_results, :next_token, :virtual_gateway_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned `nextToken` value.
If `MaxResults` is given a value larger than 100, only 100 results are returned.
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2195 class DescribeDirectConnectGatewayAssociationsRequest < Struct.new( :association_id, :associated_gateway_id, :direct_connect_gateway_id, :max_results, :next_token, :virtual_gateway_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token provided in the previous call to retrieve the next page.
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2195 class DescribeDirectConnectGatewayAssociationsRequest < Struct.new( :association_id, :associated_gateway_id, :direct_connect_gateway_id, :max_results, :next_token, :virtual_gateway_id) SENSITIVE = [] include Aws::Structure end |
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway or transit gateway.
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2195 class DescribeDirectConnectGatewayAssociationsRequest < Struct.new( :association_id, :associated_gateway_id, :direct_connect_gateway_id, :max_results, :next_token, :virtual_gateway_id) SENSITIVE = [] include Aws::Structure end |