Class: Aws::DirectConnect::Types::DescribeDirectConnectGatewayAttachmentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::DescribeDirectConnectGatewayAttachmentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Note:
When making an API call, you may pass DescribeDirectConnectGatewayAttachmentsRequest data as a hash:
{
direct_connect_gateway_id: "DirectConnectGatewayId",
virtual_interface_id: "VirtualInterfaceId",
max_results: 1,
next_token: "PaginationToken",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token provided in the previous call to retrieve the next page.
-
#virtual_interface_id ⇒ String
The ID of the virtual interface.
Instance Attribute Details
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
2256 2257 2258 2259 2260 2261 2262 2263 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2256 class DescribeDirectConnectGatewayAttachmentsRequest < Struct.new( :direct_connect_gateway_id, :virtual_interface_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned `nextToken` value.
If `MaxResults` is given a value larger than 100, only 100 results are returned.
2256 2257 2258 2259 2260 2261 2262 2263 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2256 class DescribeDirectConnectGatewayAttachmentsRequest < Struct.new( :direct_connect_gateway_id, :virtual_interface_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token provided in the previous call to retrieve the next page.
2256 2257 2258 2259 2260 2261 2262 2263 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2256 class DescribeDirectConnectGatewayAttachmentsRequest < Struct.new( :direct_connect_gateway_id, :virtual_interface_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_id ⇒ String
The ID of the virtual interface.
2256 2257 2258 2259 2260 2261 2262 2263 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2256 class DescribeDirectConnectGatewayAttachmentsRequest < Struct.new( :direct_connect_gateway_id, :virtual_interface_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |