Class: Aws::DirectConnect::Types::DescribeDirectConnectGatewaysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::DescribeDirectConnectGatewaysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Note:
When making an API call, you may pass DescribeDirectConnectGatewaysRequest data as a hash:
{
direct_connect_gateway_id: "DirectConnectGatewayId",
max_results: 1,
next_token: "PaginationToken",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token provided in the previous call to retrieve the next page.
Instance Attribute Details
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
2310 2311 2312 2313 2314 2315 2316 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2310 class DescribeDirectConnectGatewaysRequest < Struct.new( :direct_connect_gateway_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned `nextToken` value.
If `MaxResults` is given a value larger than 100, only 100 results are returned.
2310 2311 2312 2313 2314 2315 2316 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2310 class DescribeDirectConnectGatewaysRequest < Struct.new( :direct_connect_gateway_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token provided in the previous call to retrieve the next page.
2310 2311 2312 2313 2314 2315 2316 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2310 class DescribeDirectConnectGatewaysRequest < Struct.new( :direct_connect_gateway_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |