Class: Aws::DirectConnect::Types::DescribeLagsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lag_idString

The ID of the LAG.



2076
2077
2078
2079
2080
2081
2082
# File 'lib/aws-sdk-directconnect/types.rb', line 2076

class DescribeLagsRequest < Struct.new(
  :lag_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

If MaxResults is given a value larger than 100, only 100 results are returned.



2076
2077
2078
2079
2080
2081
2082
# File 'lib/aws-sdk-directconnect/types.rb', line 2076

class DescribeLagsRequest < Struct.new(
  :lag_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.



2076
2077
2078
2079
2080
2081
2082
# File 'lib/aws-sdk-directconnect/types.rb', line 2076

class DescribeLagsRequest < Struct.new(
  :lag_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end