Class: Aws::DirectConnect::Types::DirectConnectGatewayAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::DirectConnectGatewayAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about an association between a Direct Connect gateway and a virtual private gateway or transit gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_prefixes_to_direct_connect_gateway ⇒ Array<Types::RouteFilterPrefix>
The Amazon VPC prefixes to advertise to the Direct Connect gateway.
-
#associated_gateway ⇒ Types::AssociatedGateway
Information about the associated gateway.
-
#association_id ⇒ String
The ID of the Direct Connect gateway association.
-
#association_state ⇒ String
The state of the association.
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#direct_connect_gateway_owner_account ⇒ String
The ID of the Amazon Web Services account that owns the associated gateway.
-
#state_change_error ⇒ String
The error message if the state of an object failed to advance.
-
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway.
-
#virtual_gateway_owner_account ⇒ String
The ID of the Amazon Web Services account that owns the virtual private gateway.
-
#virtual_gateway_region ⇒ String
The Amazon Web Services Region where the virtual private gateway is located.
Instance Attribute Details
#allowed_prefixes_to_direct_connect_gateway ⇒ Array<Types::RouteFilterPrefix>
The Amazon VPC prefixes to advertise to the Direct Connect gateway.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#associated_gateway ⇒ Types::AssociatedGateway
Information about the associated gateway.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#association_id ⇒ String
The ID of the Direct Connect gateway association.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#association_state ⇒ String
The state of the association. The following are the possible values:
-
`associating`: The initial state after calling CreateDirectConnectGatewayAssociation.
-
`associated`: The Direct Connect gateway and virtual private gateway or transit gateway are successfully associated and ready to pass traffic.
-
`disassociating`: The initial state after calling DeleteDirectConnectGatewayAssociation.
-
`disassociated`: The virtual private gateway or transit gateway is disassociated from the Direct Connect gateway. Traffic flow between the Direct Connect gateway and virtual private gateway or transit gateway is stopped.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_owner_account ⇒ String
The ID of the Amazon Web Services account that owns the associated gateway.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#state_change_error ⇒ String
The error message if the state of an object failed to advance.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway. Applies only to private virtual interfaces.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#virtual_gateway_owner_account ⇒ String
The ID of the Amazon Web Services account that owns the virtual private gateway.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |
#virtual_gateway_region ⇒ String
The Amazon Web Services Region where the virtual private gateway is located.
2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2719 class DirectConnectGatewayAssociation < Struct.new( :direct_connect_gateway_id, :direct_connect_gateway_owner_account, :association_state, :state_change_error, :associated_gateway, :association_id, :allowed_prefixes_to_direct_connect_gateway, :virtual_gateway_id, :virtual_gateway_region, :virtual_gateway_owner_account) SENSITIVE = [] include Aws::Structure end |