Class: Aws::DirectConnect::Types::Interconnect

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Information about an interconnect.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_deviceString

The Direct Connect endpoint on which the physical connection terminates.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#aws_device_v2String

The Direct Connect endpoint that terminates the physical connection.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#aws_logical_device_idString

The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#bandwidthString

The bandwidth of the connection.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_modeString

The MAC Security (MACsec) encryption mode.

The valid values are no_encrypt, should_encrypt, and must_encrypt.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#has_logical_redundancyString

Indicates whether the interconnect supports a secondary BGP in the same address family (IPv4/IPv6).



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#interconnect_idString

The ID of the interconnect.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#interconnect_nameString

The name of the interconnect.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#interconnect_stateString

The state of the interconnect. The following are the possible values:

  • requested: The initial state of an interconnect. The interconnect stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.

  • pending: The interconnect is approved, and is being initialized.

  • available: The network link is up, and the interconnect is ready for use.

  • down: The network link is down.

  • deleting: The interconnect is being deleted.

  • deleted: The interconnect is deleted.

  • unknown: The state of the interconnect is not available.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#jumbo_frame_capableBoolean

Indicates whether jumbo frames are supported.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#lag_idString

The ID of the LAG.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#loa_issue_timeTime

The time of the most recent call to DescribeLoa for this connection.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The location of the connection.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#mac_sec_capableBoolean

Indicates whether the interconnect supports MAC Security (MACsec).



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#mac_sec_keysArray<Types::MacSecKey>

The MAC Security (MACsec) security keys.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#port_encryption_statusString

The MAC Security (MACsec) port link status.

The valid values are ‘Encryption Up`, which means that there is an active Connection Key Name, or `Encryption Down`.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The name of the service provider associated with the interconnect.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region where the connection is located.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the interconnect.



2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
# File 'lib/aws-sdk-directconnect/types.rb', line 2681

class Interconnect < Struct.new(
  :interconnect_id,
  :interconnect_name,
  :interconnect_state,
  :region,
  :location,
  :bandwidth,
  :loa_issue_time,
  :lag_id,
  :aws_device,
  :jumbo_frame_capable,
  :aws_device_v2,
  :aws_logical_device_id,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :port_encryption_status,
  :encryption_mode,
  :mac_sec_keys)
  SENSITIVE = []
  include Aws::Structure
end