Class: Aws::DirectConnect::Types::Interconnects
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::Interconnects
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#interconnects ⇒ Array<Types::Interconnect>
The interconnects.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#interconnects ⇒ Array<Types::Interconnect>
The interconnects.
3001 3002 3003 3004 3005 3006 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3001 class Interconnects < Struct.new( :interconnects, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
3001 3002 3003 3004 3005 3006 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3001 class Interconnects < Struct.new( :interconnects, :next_token) SENSITIVE = [] include Aws::Structure end |