Class: Aws::DirectConnect::Types::ListResiliencyGroupAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::ListResiliencyGroupAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::ResiliencyGroupAssociation>
The connection associations for the resiliency group.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#items ⇒ Array<Types::ResiliencyGroupAssociation>
The connection associations for the resiliency group.
3253 3254 3255 3256 3257 3258 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3253 class ListResiliencyGroupAssociationsResult < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
3253 3254 3255 3256 3257 3258 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3253 class ListResiliencyGroupAssociationsResult < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |