Class: Aws::DirectConnect::Types::Location

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Information about an Direct Connect location.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#available_billing_modesArray<Types::AvailableBillingMode>

The billing modes available at the location, including the port speeds and Amazon Web Services Regions supported by each mode.

Returns:



3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-directconnect/types.rb', line 3471

class Location < Struct.new(
  :location_code,
  :location_name,
  :region,
  :available_port_speeds,
  :available_providers,
  :available_mac_sec_port_speeds,
  :available_billing_modes)
  SENSITIVE = []
  include Aws::Structure
end

#available_mac_sec_port_speedsArray<String>

The available MAC Security (MACsec) port speeds for the location.

Returns:

  • (Array<String>)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-directconnect/types.rb', line 3471

class Location < Struct.new(
  :location_code,
  :location_name,
  :region,
  :available_port_speeds,
  :available_providers,
  :available_mac_sec_port_speeds,
  :available_billing_modes)
  SENSITIVE = []
  include Aws::Structure
end

#available_port_speedsArray<String>

The available port speeds for the location.

Returns:

  • (Array<String>)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-directconnect/types.rb', line 3471

class Location < Struct.new(
  :location_code,
  :location_name,
  :region,
  :available_port_speeds,
  :available_providers,
  :available_mac_sec_port_speeds,
  :available_billing_modes)
  SENSITIVE = []
  include Aws::Structure
end

#available_providersArray<String>

The name of the service provider for the location.

Returns:

  • (Array<String>)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-directconnect/types.rb', line 3471

class Location < Struct.new(
  :location_code,
  :location_name,
  :region,
  :available_port_speeds,
  :available_providers,
  :available_mac_sec_port_speeds,
  :available_billing_modes)
  SENSITIVE = []
  include Aws::Structure
end

#location_codeString

The code for the location.

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-directconnect/types.rb', line 3471

class Location < Struct.new(
  :location_code,
  :location_name,
  :region,
  :available_port_speeds,
  :available_providers,
  :available_mac_sec_port_speeds,
  :available_billing_modes)
  SENSITIVE = []
  include Aws::Structure
end

#location_nameString

The name of the location. This includes the name of the colocation partner and the physical site of the building.

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-directconnect/types.rb', line 3471

class Location < Struct.new(
  :location_code,
  :location_name,
  :region,
  :available_port_speeds,
  :available_providers,
  :available_mac_sec_port_speeds,
  :available_billing_modes)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region for the location.

Returns:

  • (String)


3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
# File 'lib/aws-sdk-directconnect/types.rb', line 3471

class Location < Struct.new(
  :location_code,
  :location_name,
  :region,
  :available_port_speeds,
  :available_providers,
  :available_mac_sec_port_speeds,
  :available_billing_modes)
  SENSITIVE = []
  include Aws::Structure
end