Class: Aws::DirectConnect::Types::NewPrivateVirtualInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::NewPrivateVirtualInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a private virtual interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#asn ⇒ Integer
The autonomous system number (ASN).
-
#asn_long ⇒ Integer
The long ASN for a new private virtual interface.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#enable_site_link ⇒ Boolean
Indicates whether to enable or disable SiteLink.
-
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes.
-
#rate_limit ⇒ String
The rate limit (bandwidth allocation) to apply to the virtual interface.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the private virtual interface.
-
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway.
-
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system number (ASN). The valid range is from 1 to 2147483646 for Border Gateway Protocol (BGP) configuration. If you provide a number greater than the maximum, an error is returned. Use ‘asnLong` instead.
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
-
If you enter a 4-byte ASN for the ‘asn` parameter, the API returns an error.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
The valid values are 1-2147483646.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn_long ⇒ Integer
The long ASN for a new private virtual interface. The valid range is from 1 to 4294967294 for BGP configuration.
Note the following limitations when using ‘asnLong`:
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
‘asnLong` accepts any valid ASN value, regardless if it’s 2-byte or 4-byte.
-
When using a 4-byte ‘asnLong`, the API response returns `0` for the legacy `asn` attribute since 4-byte ASN values exceed the maximum supported value of 2,147,483,647.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#enable_site_link ⇒ Boolean
Indicates whether to enable or disable SiteLink.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 8500. The default value is 1500.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#rate_limit ⇒ String
The rate limit (bandwidth allocation) to apply to the virtual interface. The rate limit restricts the maximum bandwidth that the virtual interface can use on the parent connection.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the private virtual interface.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3250 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link, :rate_limit) SENSITIVE = [] include Aws::Structure end |