Class: Aws::DirectConnect::Types::NewPrivateVirtualInterfaceAllocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::NewPrivateVirtualInterfaceAllocation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass NewPrivateVirtualInterfaceAllocation data as a hash:
{
virtual_interface_name: "VirtualInterfaceName", # required
vlan: 1, # required
asn: 1, # required
mtu: 1,
auth_key: "BGPAuthKey",
amazon_address: "AmazonAddress",
address_family: "ipv4", # accepts ipv4, ipv6
customer_address: "CustomerAddress",
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Information about a private virtual interface to be provisioned on a connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#asn ⇒ Integer
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the private virtual interface.
-
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
The valid values are 1-2147483647.
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 9001. The default value is 1500.
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the private virtual interface.
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3626 class NewPrivateVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :address_family, :customer_address, :tags) SENSITIVE = [] include Aws::Structure end |