Class: Aws::DirectConnect::Types::NewPublicVirtualInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::NewPublicVirtualInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a public virtual interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#asn ⇒ Integer
The autonomous system number (ASN).
-
#asn_long ⇒ Integer
The long ASN for a new public virtual interface.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#rate_limit ⇒ String
The rate limit (bandwidth allocation) to apply to the virtual interface.
-
#route_filter_prefixes ⇒ Array<Types::RouteFilterPrefix>
The routes to be advertised to the Amazon Web Services network in this Region.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the public virtual interface.
-
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system number (ASN). The valid range is from 1 to 2147483646 for Border Gateway Protocol (BGP) configuration. If you provide a number greater than the maximum, an error is returned. Use ‘asnLong` instead.
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
-
If you enter a 4-byte ASN for the ‘asn` parameter, the API returns an error.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn_long ⇒ Integer
The long ASN for a new public virtual interface. The valid range is from 1 to 4294967294 for BGP configuration.
Note the following limitations when using ‘asnLong`:
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
‘asnLong` accepts any valid ASN value, regardless if it’s 2-byte or 4-byte.
-
When using a 4-byte ‘asnLong`, the API response returns `0` for the legacy `asn` attribute since 4-byte ASN values exceed the maximum supported value of 2,147,483,647.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#rate_limit ⇒ String
The rate limit (bandwidth allocation) to apply to the virtual interface. The rate limit restricts the maximum bandwidth that the virtual interface can use on the parent connection.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#route_filter_prefixes ⇒ Array<Types::RouteFilterPrefix>
The routes to be advertised to the Amazon Web Services network in this Region. Applies to public virtual interfaces.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the public virtual interface.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3466 class NewPublicVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags, :rate_limit) SENSITIVE = [] include Aws::Structure end |