Class: Aws::DirectConnect::Types::NewPublicVirtualInterfaceAllocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::NewPublicVirtualInterfaceAllocation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass NewPublicVirtualInterfaceAllocation data as a hash:
{
virtual_interface_name: "VirtualInterfaceName", # required
vlan: 1, # required
asn: 1, # required
auth_key: "BGPAuthKey",
amazon_address: "AmazonAddress",
customer_address: "CustomerAddress",
address_family: "ipv4", # accepts ipv4, ipv6
route_filter_prefixes: [
{
cidr: "CIDR",
},
],
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Information about a public virtual interface to be provisioned on a connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#asn ⇒ Integer
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#route_filter_prefixes ⇒ Array<Types::RouteFilterPrefix>
The routes to be advertised to the Amazon Web Services network in this Region.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the public virtual interface.
-
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
The valid values are 1-2147483647.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |
#route_filter_prefixes ⇒ Array<Types::RouteFilterPrefix>
The routes to be advertised to the Amazon Web Services network in this Region. Applies to public virtual interfaces.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the public virtual interface.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3799 class NewPublicVirtualInterfaceAllocation < Struct.new( :virtual_interface_name, :vlan, :asn, :auth_key, :amazon_address, :customer_address, :address_family, :route_filter_prefixes, :tags) SENSITIVE = [] include Aws::Structure end |