Class: Aws::DirectConnect::Types::NewTransitVirtualInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::NewTransitVirtualInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a transit virtual interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#asn ⇒ Integer
The autonomous system number (ASN).
-
#asn_long ⇒ Integer
The long ASN for a new transit virtual interface.The valid range is from 1 to 4294967294 for BGP configuration.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#enable_site_link ⇒ Boolean
Indicates whether to enable or disable SiteLink.
-
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes.
-
#prefix_pool_allocated_count_ipv_4 ⇒ Integer
The number of inbound IPv4 route prefixes to allocate to the virtual interface.
-
#prefix_pool_allocated_count_ipv_6 ⇒ Integer
The number of inbound IPv6 route prefixes to allocate to the virtual interface.
-
#rate_limit ⇒ String
The rate limit (bandwidth allocation) to apply to the virtual interface.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the transitive virtual interface.
-
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system number (ASN). The valid range is from 1 to
2147483646 for Border Gateway Protocol (BGP) configuration. If you
provide a number greater than the maximum, an error is returned. Use
asnLong instead.
-
You can use
asnLongorasn, but not both. We recommend usingasnLongas it supports a greater pool of numbers. -
If you provide a value in the same API call for both
asnandasnLong, the API will only accept the value forasnLong. -
If you enter a 4-byte ASN for the
asnparameter, the API returns an error. -
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the
asnandasnLongfields.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn_long ⇒ Integer
The long ASN for a new transit virtual interface.The valid range is from 1 to 4294967294 for BGP configuration.
Note the following limitations when using asnLong:
-
You can use
asnLongorasn, but not both. We recommend usingasnLongas it supports a greater pool of numbers. -
asnLongaccepts any valid ASN value, regardless if it's 2-byte or 4-byte. -
When using a 4-byte
asnLong, the API response returns0for the legacyasnattribute since 4-byte ASN values exceed the maximum supported value of 2,147,483,647. -
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the
asnandasnLongfields. -
If you provide a value in the same API call for both
asnandasnLong, the API will only accept the value forasnLong.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#enable_site_link ⇒ Boolean
Indicates whether to enable or disable SiteLink.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 8500. The default value is 1500.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#prefix_pool_allocated_count_ipv_4 ⇒ Integer
The number of inbound IPv4 route prefixes to allocate to the virtual interface.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#prefix_pool_allocated_count_ipv_6 ⇒ Integer
The number of inbound IPv6 route prefixes to allocate to the virtual interface.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#rate_limit ⇒ String
The rate limit (bandwidth allocation) to apply to the virtual interface. The rate limit restricts the maximum bandwidth that the virtual interface can use on the parent connection.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the transitive virtual interface.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4147 class NewTransitVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :asn_long, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :direct_connect_gateway_id, :tags, :enable_site_link, :prefix_pool_allocated_count_ipv_4, :prefix_pool_allocated_count_ipv_6, :rate_limit) SENSITIVE = [] include Aws::Structure end |