Class: Aws::DirectConnect::Types::NewTransitVirtualInterfaceAllocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Information about a transit virtual interface to be provisioned on a connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#address_familyString

The address family for the BGP peer.

Returns:

  • (String)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#amazon_addressString

The IP address assigned to the Amazon interface.

Returns:

  • (String)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#asnInteger

The autonomous system number (ASN). The valid range is from 1 to 2147483646 for Border Gateway Protocol (BGP) configuration. If you provide a number greater than the maximum, an error is returned. Use ‘asnLong` instead.

  • You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.

  • If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.

  • If you enter a 4-byte ASN for the ‘asn` parameter, the API returns an error.

  • If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.

The valid values are 1-2147483646.

Returns:

  • (Integer)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#asn_longInteger

The ASN when allocating a new transit virtual interface. The valid range is from 1 to 4294967294 for BGP configuration.

Note the following limitations when using ‘asnLong`:

  • You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.

  • ‘asnLong` accepts any valid ASN value, regardless if it’s 2-byte or 4-byte.

  • When using a 4-byte ‘asnLong`, the API response returns `0` for the legacy `asn` attribute since 4-byte ASN values exceed the maximum supported value of 2,147,483,647.

  • If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.

  • If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.

Returns:

  • (Integer)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#auth_keyString

The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.

Returns:

  • (String)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#customer_addressString

The IP address assigned to the customer interface.

Returns:

  • (String)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#mtuInteger

The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 8500. The default value is 1500

Returns:

  • (Integer)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#rate_limitString

The rate limit (bandwidth allocation) to apply to the virtual interface. The rate limit restricts the maximum bandwidth that the virtual interface can use on the parent connection.

Returns:

  • (String)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the transitive virtual interface.

Returns:



3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#virtual_interface_nameString

The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).

Returns:

  • (String)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end

#vlanInteger

The ID of the VLAN.

Returns:

  • (Integer)


3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-directconnect/types.rb', line 3797

class NewTransitVirtualInterfaceAllocation < Struct.new(
  :virtual_interface_name,
  :vlan,
  :asn,
  :asn_long,
  :mtu,
  :auth_key,
  :amazon_address,
  :customer_address,
  :address_family,
  :tags,
  :rate_limit)
  SENSITIVE = []
  include Aws::Structure
end