Class: Aws::DirectConnect::Types::RateLimiterStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Contains information about the rate limiter status for a connection, including the maximum number of rate limiters allowed, the number currently in use, and the remaining capacity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#in_useInteger

The number of rate limiters currently in use on the connection.

Returns:

  • (Integer)


3836
3837
3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-directconnect/types.rb', line 3836

class RateLimiterStatus < Struct.new(
  :max_allowed,
  :in_use,
  :remaining,
  :total_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#max_allowedInteger

The maximum number of rate limiters allowed on the connection.

Returns:

  • (Integer)


3836
3837
3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-directconnect/types.rb', line 3836

class RateLimiterStatus < Struct.new(
  :max_allowed,
  :in_use,
  :remaining,
  :total_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#remainingInteger

The number of rate limiters remaining (available) on the connection.

Returns:

  • (Integer)


3836
3837
3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-directconnect/types.rb', line 3836

class RateLimiterStatus < Struct.new(
  :max_allowed,
  :in_use,
  :remaining,
  :total_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#total_bandwidthString

The total bandwidth allocated across all rate limiters on the connection.

Returns:

  • (String)


3836
3837
3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-directconnect/types.rb', line 3836

class RateLimiterStatus < Struct.new(
  :max_allowed,
  :in_use,
  :remaining,
  :total_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end