Class: Aws::DirectConnect::Types::ResiliencyGroupSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::ResiliencyGroupSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Summary information about a resiliency group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the resiliency group.
-
#resiliency_group_arn ⇒ String
The Amazon Resource Name (ARN) of the resiliency group.
-
#resiliency_group_id ⇒ String
The ID of the resiliency group.
-
#resiliency_group_name ⇒ String
The name of the resiliency group.
-
#resiliency_group_type ⇒ String
The type of the resiliency group.
-
#state ⇒ String
The state of the resiliency group.
Instance Attribute Details
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the resiliency group.
4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4408 class ResiliencyGroupSummary < Struct.new( :resiliency_group_id, :resiliency_group_arn, :resiliency_group_name, :resiliency_group_type, :owner_account, :state) SENSITIVE = [] include Aws::Structure end |
#resiliency_group_arn ⇒ String
The Amazon Resource Name (ARN) of the resiliency group.
4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4408 class ResiliencyGroupSummary < Struct.new( :resiliency_group_id, :resiliency_group_arn, :resiliency_group_name, :resiliency_group_type, :owner_account, :state) SENSITIVE = [] include Aws::Structure end |
#resiliency_group_id ⇒ String
The ID of the resiliency group.
4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4408 class ResiliencyGroupSummary < Struct.new( :resiliency_group_id, :resiliency_group_arn, :resiliency_group_name, :resiliency_group_type, :owner_account, :state) SENSITIVE = [] include Aws::Structure end |
#resiliency_group_name ⇒ String
The name of the resiliency group.
4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4408 class ResiliencyGroupSummary < Struct.new( :resiliency_group_id, :resiliency_group_arn, :resiliency_group_name, :resiliency_group_type, :owner_account, :state) SENSITIVE = [] include Aws::Structure end |
#resiliency_group_type ⇒ String
The type of the resiliency group. The valid value is Managed.
4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4408 class ResiliencyGroupSummary < Struct.new( :resiliency_group_id, :resiliency_group_arn, :resiliency_group_name, :resiliency_group_type, :owner_account, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the resiliency group.
4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4408 class ResiliencyGroupSummary < Struct.new( :resiliency_group_id, :resiliency_group_arn, :resiliency_group_name, :resiliency_group_type, :owner_account, :state) SENSITIVE = [] include Aws::Structure end |