Class: Aws::DirectConnect::Types::Route
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::Route
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a route for a virtual interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family of the route.
-
#as_path ⇒ Array<Types::AsPathSegment>
The autonomous system (AS) path of the route.
-
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection.
-
#cidr ⇒ String
The CIDR (prefix) of the route.
-
#communities ⇒ Array<String>
The BGP communities associated with the route.
-
#route_direction ⇒ String
The direction of the route.
-
#route_installed_at ⇒ Time
The time when the route was installed.
Instance Attribute Details
#address_family ⇒ String
The address family of the route.
The valid values are ipv4 and ipv6.
4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4068 class Route < Struct.new( :cidr, :route_direction, :address_family, :as_path, :communities, :aws_logical_device_id, :route_installed_at) SENSITIVE = [] include Aws::Structure end |
#as_path ⇒ Array<Types::AsPathSegment>
The autonomous system (AS) path of the route.
4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4068 class Route < Struct.new( :cidr, :route_direction, :address_family, :as_path, :communities, :aws_logical_device_id, :route_installed_at) SENSITIVE = [] include Aws::Structure end |
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.
4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4068 class Route < Struct.new( :cidr, :route_direction, :address_family, :as_path, :communities, :aws_logical_device_id, :route_installed_at) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
The CIDR (prefix) of the route.
4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4068 class Route < Struct.new( :cidr, :route_direction, :address_family, :as_path, :communities, :aws_logical_device_id, :route_installed_at) SENSITIVE = [] include Aws::Structure end |
#communities ⇒ Array<String>
The BGP communities associated with the route.
4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4068 class Route < Struct.new( :cidr, :route_direction, :address_family, :as_path, :communities, :aws_logical_device_id, :route_installed_at) SENSITIVE = [] include Aws::Structure end |
#route_direction ⇒ String
The direction of the route.
The valid values are accepted (received from the customer network)
and advertised (advertised to the customer network).
4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4068 class Route < Struct.new( :cidr, :route_direction, :address_family, :as_path, :communities, :aws_logical_device_id, :route_installed_at) SENSITIVE = [] include Aws::Structure end |
#route_installed_at ⇒ Time
The time when the route was installed. The value is displayed in UTC format.
4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4068 class Route < Struct.new( :cidr, :route_direction, :address_family, :as_path, :communities, :aws_logical_device_id, :route_installed_at) SENSITIVE = [] include Aws::Structure end |