Class: Aws::DirectConnect::Types::UpdateConnectionsBillingModeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::UpdateConnectionsBillingModeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_mode ⇒ String
The billing mode to apply to the specified connections.
-
#connection_ids ⇒ Array<String>
The IDs of the connections to update.
Instance Attribute Details
#billing_mode ⇒ String
The billing mode to apply to the specified connections. The valid
values are PayAsYouGo, FlatRateTier1, FlatRateTier2,
FlatRateTier3, FlatRateTier4, and FlatRateTier5.
4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4761 class UpdateConnectionsBillingModeRequest < Struct.new( :connection_ids, :billing_mode) SENSITIVE = [] include Aws::Structure end |
#connection_ids ⇒ Array<String>
The IDs of the connections to update. You can specify from 1 to 200 connections.
4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4761 class UpdateConnectionsBillingModeRequest < Struct.new( :connection_ids, :billing_mode) SENSITIVE = [] include Aws::Structure end |