Class: Aws::DirectConnect::Types::VirtualInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::VirtualInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a virtual interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#amazon_side_asn ⇒ Integer
The autonomous system number (AS) for the Amazon side of the connection.
-
#asn ⇒ Integer
The autonomous system number (ASN).
-
#asn_long ⇒ Integer
The long ASN for the virtual interface.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#aws_device_v2 ⇒ String
The Direct Connect endpoint that terminates the physical connection.
-
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection.
-
#bgp_peers ⇒ Array<Types::BGPPeer>
The BGP peers configured on this virtual interface.
-
#connection_id ⇒ String
The ID of the connection.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#customer_router_config ⇒ String
The customer router configuration.
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
-
#location ⇒ String
The location of the connection.
-
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes.
-
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the virtual interface.
-
#rate_limit ⇒ String
The rate limit (bandwidth allocation) applied to the virtual interface.
-
#region ⇒ String
The Amazon Web Services Region where the virtual interface is located.
-
#route_filter_prefixes ⇒ Array<Types::RouteFilterPrefix>
The routes to be advertised to the Amazon Web Services network in this Region.
-
#site_link_enabled ⇒ Boolean
Indicates whether SiteLink is enabled.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the virtual interface.
-
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway.
-
#virtual_interface_id ⇒ String
The ID of the virtual interface.
-
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network.
-
#virtual_interface_state ⇒ String
The state of the virtual interface.
-
#virtual_interface_type ⇒ String
The type of virtual interface.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#amazon_side_asn ⇒ Integer
The autonomous system number (AS) for the Amazon side of the connection.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system number (ASN). The valid range is from 1 to
2147483646 for Border Gateway Protocol (BGP) configuration. If you
provide a number greater than the maximum, an error is returned. Use
asnLong instead.
-
You can use
asnLongorasn, but not both. We recommend usingasnLongas it supports a greater pool of numbers. -
If you provide a value in the same API call for both
asnandasnLong, the API will only accept the value forasnLong. -
If you enter a 4-byte ASN for the
asnparameter, the API returns an error. -
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the
asnandasnLongfields.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn_long ⇒ Integer
The long ASN for the virtual interface. The valid range is from 1 to 4294967294 for BGP configuration.
Note the following limitations when using asnLong:
-
You can use
asnLongorasn, but not both. We recommend usingasnLongas it supports a greater pool of numbers. -
asnLongaccepts any valid ASN value, regardless if it's 2-byte or 4-byte. -
When using a 4-byte
asnLong, the API response returns0for the legacyasnattribute since 4-byte ASN values exceed the maximum supported value of 2,147,483,647. -
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the
asnandasnLongfields. -
If you provide a value in the same API call for both
asnandasnLong, the API will only accept the value forasnLong.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#aws_device_v2 ⇒ String
The Direct Connect endpoint that terminates the physical connection.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#bgp_peers ⇒ Array<Types::BGPPeer>
The BGP peers configured on this virtual interface.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of the connection.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#customer_router_config ⇒ String
The customer router configuration.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the connection.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 8500. The default value is 1500
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the virtual interface.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#rate_limit ⇒ String
The rate limit (bandwidth allocation) applied to the virtual
interface. The value must be one of the supported bandwidth values
and cannot exceed the bandwidth of the parent connection or LAG.
Supported values: 50Mbps, 100Mbps, 200Mbps, 300Mbps,
400Mbps, 500Mbps, 600Mbps, 700Mbps, 800Mbps, 900Mbps,
1Gbps, 1.2Gbps, 1.5Gbps, 1.8Gbps, 2Gbps, 2.1Gbps,
2.4Gbps, 2.7Gbps, 3Gbps, 3.2Gbps, 3.6Gbps, 4Gbps,
5Gbps, 6Gbps, 7Gbps, 8Gbps, 9Gbps, 10Gbps, 12Gbps,
15Gbps, 18Gbps, 20Gbps, 21Gbps, 24Gbps, 27Gbps,
30Gbps, 32Gbps, 36Gbps, 40Gbps, 50Gbps, 60Gbps,
70Gbps, 80Gbps, 100Gbps, 120Gbps, 150Gbps, 180Gbps,
200Gbps, 210Gbps, 240Gbps, 270Gbps, 300Gbps, 320Gbps,
360Gbps, 400Gbps, 450Gbps, 480Gbps, 500Gbps, 540Gbps,
600Gbps, 700Gbps, 800Gbps, 900Gbps, 1Tbps, 1.1Tbps,
1.2Tbps, 1.3Tbps, 1.4Tbps, 1.5Tbps, 1.6Tbps.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region where the virtual interface is located.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#route_filter_prefixes ⇒ Array<Types::RouteFilterPrefix>
The routes to be advertised to the Amazon Web Services network in this Region. Applies to public virtual interfaces.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#site_link_enabled ⇒ Boolean
Indicates whether SiteLink is enabled.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the virtual interface.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway. Applies only to private virtual interfaces.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_id ⇒ String
The ID of the virtual interface.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_state ⇒ String
The state of the virtual interface. The following are the possible values:
-
confirming: The creation of the virtual interface is pending confirmation from the virtual interface owner. If the owner of the virtual interface is different from the owner of the connection on which it is provisioned, then the virtual interface will remain in this state until it is confirmed by the virtual interface owner. -
verifying: This state only applies to public virtual interfaces. Each public virtual interface needs validation before the virtual interface can be created. -
pending: A virtual interface is in this state from the time that it is created until the virtual interface is ready to forward traffic. -
available: A virtual interface that is able to forward traffic. -
down: A virtual interface that is BGP down. -
testing: A virtual interface is in this state immediately after calling StartBgpFailoverTest and remains in this state during the duration of the test. -
deleting: A virtual interface is in this state immediately after calling DeleteVirtualInterface until it can no longer forward traffic. -
deleted: A virtual interface that cannot forward traffic. -
rejected: The virtual interface owner has declined creation of the virtual interface. If a virtual interface in theConfirmingstate is deleted by the virtual interface owner, the virtual interface enters theRejectedstate. -
unknown: The state of the virtual interface is not available.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_type ⇒ String
The type of virtual interface. The possible values are private,
public and transit.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4641 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |