Class: Aws::DirectConnect::Types::VirtualInterfaces
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::VirtualInterfaces
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#virtual_interfaces ⇒ Array<Types::VirtualInterface>
The virtual interfaces.
Instance Attribute Details
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is ‘null` when there are no more results to return.
4552 4553 4554 4555 4556 4557 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4552 class VirtualInterfaces < Struct.new( :virtual_interfaces, :next_token) SENSITIVE = [] include Aws::Structure end |
#virtual_interfaces ⇒ Array<Types::VirtualInterface>
The virtual interfaces
4552 4553 4554 4555 4556 4557 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4552 class VirtualInterfaces < Struct.new( :virtual_interfaces, :next_token) SENSITIVE = [] include Aws::Structure end |