Class: Aws::DirectConnect::Types::AssociateMacSecKeyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::AssociateMacSecKeyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass AssociateMacSecKeyRequest data as a hash:
{
connection_id: "ConnectionId", # required
secret_arn: "SecretARN",
ckn: "Ckn",
cak: "Cak",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cak ⇒ String
The MAC Security (MACsec) CAK to associate with the dedicated connection.
-
#ckn ⇒ String
The MAC Security (MACsec) CKN to associate with the dedicated connection.
-
#connection_id ⇒ String
The ID of the dedicated connection (dxcon-xxxx), or the ID of the LAG (dxlag-xxxx).
-
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the MAC Security (MACsec) secret key to associate with the dedicated connection.
Instance Attribute Details
#cak ⇒ String
The MAC Security (MACsec) CAK to associate with the dedicated connection.
You can create the CKN/CAK pair using an industry standard tool.
The valid values are 64 hexadecimal characters (0-9, A-E).
If you use this request parameter, you must use the `ckn` request parameter and not use the `secretARN` request parameter.
449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-directconnect/types.rb', line 449 class AssociateMacSecKeyRequest < Struct.new( :connection_id, :secret_arn, :ckn, :cak) SENSITIVE = [] include Aws::Structure end |
#ckn ⇒ String
The MAC Security (MACsec) CKN to associate with the dedicated connection.
You can create the CKN/CAK pair using an industry standard tool.
The valid values are 64 hexadecimal characters (0-9, A-E).
If you use this request parameter, you must use the `cak` request parameter and not use the `secretARN` request parameter.
449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-directconnect/types.rb', line 449 class AssociateMacSecKeyRequest < Struct.new( :connection_id, :secret_arn, :ckn, :cak) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of the dedicated connection (dxcon-xxxx), or the ID of the LAG (dxlag-xxxx).
You can use DescribeConnections or DescribeLags to retrieve connection ID.
449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-directconnect/types.rb', line 449 class AssociateMacSecKeyRequest < Struct.new( :connection_id, :secret_arn, :ckn, :cak) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the MAC Security (MACsec) secret key to associate with the dedicated connection.
You can use DescribeConnections or DescribeLags to retrieve the MAC Security (MACsec) secret key.
If you use this request parameter, you do not use the `ckn` and `cak` request parameters.
449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-directconnect/types.rb', line 449 class AssociateMacSecKeyRequest < Struct.new( :connection_id, :secret_arn, :ckn, :cak) SENSITIVE = [] include Aws::Structure end |