Class: Aws::DirectConnect::Types::CreateConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bandwidthString

The bandwidth of the connection.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-directconnect/types.rb', line 1076

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

The name of the connection.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-directconnect/types.rb', line 1076

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#lag_idString

The ID of the LAG.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-directconnect/types.rb', line 1076

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The location of the connection.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-directconnect/types.rb', line 1076

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The name of the service provider associated with the requested connection.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-directconnect/types.rb', line 1076

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#request_mac_secBoolean

Indicates whether you want the connection to support MAC Security (MACsec).

MAC Security (MACsec) is unavailable on hosted connections. For information about MAC Security (MACsec) prerequisites, see MAC Security in Direct Connect in the Direct Connect User Guide.

Returns:

  • (Boolean)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-directconnect/types.rb', line 1076

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags to associate with the lag.

Returns:



1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-directconnect/types.rb', line 1076

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end