Class: Aws::DirectConnect::Types::CreateConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Note:

When making an API call, you may pass CreateConnectionRequest data as a hash:

{
  location: "LocationCode", # required
  bandwidth: "Bandwidth", # required
  connection_name: "ConnectionName", # required
  lag_id: "LagId",
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue",
    },
  ],
  provider_name: "ProviderName",
  request_mac_sec: false,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bandwidthString

The bandwidth of the connection.

Returns:

  • (String)


1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-directconnect/types.rb', line 1183

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

The name of the connection.

Returns:

  • (String)


1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-directconnect/types.rb', line 1183

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#lag_idString

The ID of the LAG.

Returns:

  • (String)


1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-directconnect/types.rb', line 1183

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The location of the connection.

Returns:

  • (String)


1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-directconnect/types.rb', line 1183

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The name of the service provider associated with the requested connection.

Returns:

  • (String)


1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-directconnect/types.rb', line 1183

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#request_mac_secBoolean

Indicates whether you want the connection to support MAC Security (MACsec).

MAC Security (MACsec) is only available on dedicated connections. For information about MAC Security (MACsec) prerequisties, see

MACsec prerequisties][1

in the *Direct Connect User Guide*.

[1]: docs.aws.amazon.com/directconnect/latest/UserGuide/direct-connect-mac-sec-getting-started.html#mac-sec-prerequisites

Returns:

  • (Boolean)


1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-directconnect/types.rb', line 1183

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags to associate with the lag.

Returns:



1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-directconnect/types.rb', line 1183

class CreateConnectionRequest < Struct.new(
  :location,
  :bandwidth,
  :connection_name,
  :lag_id,
  :tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end