Class: Aws::DirectConnect::Types::CreateConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::CreateConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass CreateConnectionRequest data as a hash:
{
location: "LocationCode", # required
bandwidth: "Bandwidth", # required
connection_name: "ConnectionName", # required
lag_id: "LagId",
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
provider_name: "ProviderName",
request_mac_sec: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth ⇒ String
The bandwidth of the connection.
-
#connection_name ⇒ String
The name of the connection.
-
#lag_id ⇒ String
The ID of the LAG.
-
#location ⇒ String
The location of the connection.
-
#provider_name ⇒ String
The name of the service provider associated with the requested connection.
-
#request_mac_sec ⇒ Boolean
Indicates whether you want the connection to support MAC Security (MACsec).
-
#tags ⇒ Array<Types::Tag>
The tags to associate with the lag.
Instance Attribute Details
#bandwidth ⇒ String
The bandwidth of the connection.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1183 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the connection.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1183 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#lag_id ⇒ String
The ID of the LAG.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1183 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the connection.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1183 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the requested connection.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1183 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#request_mac_sec ⇒ Boolean
Indicates whether you want the connection to support MAC Security (MACsec).
MAC Security (MACsec) is only available on dedicated connections. For information about MAC Security (MACsec) prerequisties, see
- MACsec prerequisties][1
-
in the *Direct Connect User Guide*.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1183 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to associate with the lag.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1183 class CreateConnectionRequest < Struct.new( :location, :bandwidth, :connection_name, :lag_id, :tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |