Class: Aws::DirectConnect::Types::CreateDirectConnectGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::CreateDirectConnectGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Note:
When making an API call, you may pass CreateDirectConnectGatewayRequest data as a hash:
{
direct_connect_gateway_name: "DirectConnectGatewayName", # required
amazon_side_asn: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_side_asn ⇒ Integer
The autonomous system number (ASN) for Border Gateway Protocol (BGP) to be configured on the Amazon side of the connection.
-
#direct_connect_gateway_name ⇒ String
The name of the Direct Connect gateway.
Instance Attribute Details
#amazon_side_asn ⇒ Integer
The autonomous system number (ASN) for Border Gateway Protocol (BGP) to be configured on the Amazon side of the connection. The ASN must be in the private range of 64,512 to 65,534 or 4,200,000,000 to 4,294,967,294. The default is 64512.
1344 1345 1346 1347 1348 1349 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1344 class CreateDirectConnectGatewayRequest < Struct.new( :direct_connect_gateway_name, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_name ⇒ String
The name of the Direct Connect gateway.
1344 1345 1346 1347 1348 1349 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1344 class CreateDirectConnectGatewayRequest < Struct.new( :direct_connect_gateway_name, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |