Class: Aws::DirectConnect::Types::CreateLagRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#child_connection_tagsArray<Types::Tag>

The tags to associate with the automtically created LAGs.

Returns:



1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#connection_idString

The ID of an existing dedicated connection to migrate to the LAG.

Returns:

  • (String)


1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#connections_bandwidthString

The bandwidth of the individual physical dedicated connections bundled by the LAG. The possible values are 1Gbps,10Gbps, 100Gbps, and 400Gbps.

Returns:

  • (String)


1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#lag_nameString

The name of the LAG.

Returns:

  • (String)


1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The location for the LAG.

Returns:

  • (String)


1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_connectionsInteger

The number of physical dedicated connections initially provisioned and bundled by the LAG. You can have a maximum of four connections when the port speed is 1Gbps or 10Gbps, or two when the port speed is 100Gbps or 400Gbps.

Returns:

  • (Integer)


1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The name of the service provider associated with the LAG.

Returns:

  • (String)


1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#request_mac_secBoolean

Indicates whether the connection will support MAC Security (MACsec).

All connections in the LAG must be capable of supporting MAC Security (MACsec). For information about MAC Security (MACsec) prerequisties, see MACsec prerequisties in the Direct Connect User Guide.

Returns:

  • (Boolean)


1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags to associate with the LAG.

Returns:



1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/aws-sdk-directconnect/types.rb', line 1317

class CreateLagRequest < Struct.new(
  :number_of_connections,
  :location,
  :connections_bandwidth,
  :lag_name,
  :connection_id,
  :tags,
  :child_connection_tags,
  :provider_name,
  :request_mac_sec)
  SENSITIVE = []
  include Aws::Structure
end