Class: Aws::DirectConnect::Types::CreateLagRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::CreateLagRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#child_connection_tags ⇒ Array<Types::Tag>
The tags to associate with the automtically created LAGs.
-
#connection_id ⇒ String
The ID of an existing dedicated connection to migrate to the LAG.
-
#connections_bandwidth ⇒ String
The bandwidth of the individual physical dedicated connections bundled by the LAG.
-
#lag_name ⇒ String
The name of the LAG.
-
#location ⇒ String
The location for the LAG.
-
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG.
-
#provider_name ⇒ String
The name of the service provider associated with the LAG.
-
#request_mac_sec ⇒ Boolean
Indicates whether the connection will support MAC Security (MACsec).
-
#tags ⇒ Array<Types::Tag>
The tags to associate with the LAG.
Instance Attribute Details
#child_connection_tags ⇒ Array<Types::Tag>
The tags to associate with the automtically created LAGs.
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of an existing dedicated connection to migrate to the LAG.
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#connections_bandwidth ⇒ String
The bandwidth of the individual physical dedicated connections bundled by the LAG. The possible values are 1Gbps,10Gbps, 100Gbps, and 400Gbps.
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#lag_name ⇒ String
The name of the LAG.
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location for the LAG.
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG. You can have a maximum of four connections when the port speed is 1Gbps or 10Gbps, or two when the port speed is 100Gbps or 400Gbps.
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the LAG.
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#request_mac_sec ⇒ Boolean
Indicates whether the connection will support MAC Security (MACsec).
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to associate with the LAG.
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1317 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |