Class: Aws::DirectConnect::Types::CreateLagRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::CreateLagRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass CreateLagRequest data as a hash:
{
number_of_connections: 1, # required
location: "LocationCode", # required
connections_bandwidth: "Bandwidth", # required
lag_name: "LagName", # required
connection_id: "ConnectionId",
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
child_connection_tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
provider_name: "ProviderName",
request_mac_sec: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#child_connection_tags ⇒ Array<Types::Tag>
The tags to associate with the automtically created LAGs.
-
#connection_id ⇒ String
The ID of an existing dedicated connection to migrate to the LAG.
-
#connections_bandwidth ⇒ String
The bandwidth of the individual physical dedicated connections bundled by the LAG.
-
#lag_name ⇒ String
The name of the LAG.
-
#location ⇒ String
The location for the LAG.
-
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG.
-
#provider_name ⇒ String
The name of the service provider associated with the LAG.
-
#request_mac_sec ⇒ Boolean
Indicates whether the connection will support MAC Security (MACsec).
-
#tags ⇒ Array<Types::Tag>
The tags to associate with the LAG.
Instance Attribute Details
#child_connection_tags ⇒ Array<Types::Tag>
The tags to associate with the automtically created LAGs.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of an existing dedicated connection to migrate to the LAG.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#connections_bandwidth ⇒ String
The bandwidth of the individual physical dedicated connections bundled by the LAG. The possible values are 1Gbps and 10Gbps.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#lag_name ⇒ String
The name of the LAG.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location for the LAG.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the LAG.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#request_mac_sec ⇒ Boolean
Indicates whether the connection will support MAC Security (MACsec).
<note markdown=“1”> All connections in the LAG must be capable of supporting MAC Security (MACsec). For information about MAC Security (MACsec) prerequisties, see [MACsec prerequisties] in the *Direct Connect User Guide*.
</note>
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to associate with the LAG.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1493 class CreateLagRequest < Struct.new( :number_of_connections, :location, :connections_bandwidth, :lag_name, :connection_id, :tags, :child_connection_tags, :provider_name, :request_mac_sec) SENSITIVE = [] include Aws::Structure end |