Class: Aws::DirectConnect::Types::DeleteBGPPeerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::DeleteBGPPeerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asn ⇒ Integer
The autonomous system number (ASN).
-
#asn_long ⇒ Integer
The long ASN for the BGP peer to be deleted from a Direct Connect virtual interface.
-
#bgp_peer_id ⇒ String
The ID of the BGP peer.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#virtual_interface_id ⇒ String
The ID of the virtual interface.
Instance Attribute Details
#asn ⇒ Integer
The autonomous system number (ASN). The valid range is from 1 to 2147483646 for Border Gateway Protocol (BGP) configuration. If you provide a number greater than the maximum, an error is returned. Use ‘asnLong` instead.
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
-
If you enter a 4-byte ASN for the ‘asn` parameter, the API returns an error.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
1449 1450 1451 1452 1453 1454 1455 1456 1457 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1449 class DeleteBGPPeerRequest < Struct.new( :virtual_interface_id, :asn, :asn_long, :customer_address, :bgp_peer_id) SENSITIVE = [] include Aws::Structure end |
#asn_long ⇒ Integer
The long ASN for the BGP peer to be deleted from a Direct Connect virtual interface. The valid range is from 1 to 4294967294 for BGP configuration.
Note the following limitations when using ‘asnLong`:
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
‘asnLong` accepts any valid ASN value, regardless if it’s 2-byte or 4-byte.
-
When using a 4-byte ‘asnLong`, the API response returns `0` for the legacy `asn` attribute since 4-byte ASN values exceed the maximum supported value of 2,147,483,647.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
1449 1450 1451 1452 1453 1454 1455 1456 1457 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1449 class DeleteBGPPeerRequest < Struct.new( :virtual_interface_id, :asn, :asn_long, :customer_address, :bgp_peer_id) SENSITIVE = [] include Aws::Structure end |
#bgp_peer_id ⇒ String
The ID of the BGP peer.
1449 1450 1451 1452 1453 1454 1455 1456 1457 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1449 class DeleteBGPPeerRequest < Struct.new( :virtual_interface_id, :asn, :asn_long, :customer_address, :bgp_peer_id) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
1449 1450 1451 1452 1453 1454 1455 1456 1457 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1449 class DeleteBGPPeerRequest < Struct.new( :virtual_interface_id, :asn, :asn_long, :customer_address, :bgp_peer_id) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_id ⇒ String
The ID of the virtual interface.
1449 1450 1451 1452 1453 1454 1455 1456 1457 |
# File 'lib/aws-sdk-directconnect/types.rb', line 1449 class DeleteBGPPeerRequest < Struct.new( :virtual_interface_id, :asn, :asn_long, :customer_address, :bgp_peer_id) SENSITIVE = [] include Aws::Structure end |