Class: Aws::DirectConnect::Types::Interconnect
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::Interconnect
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about an interconnect.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_device ⇒ String
The Direct Connect endpoint on which the physical connection terminates.
-
#aws_device_v2 ⇒ String
The Direct Connect endpoint that terminates the physical connection.
-
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection.
-
#bandwidth ⇒ String
The bandwidth of the connection.
-
#encryption_mode ⇒ String
The MAC Security (MACsec) encryption mode.
-
#has_logical_redundancy ⇒ String
Indicates whether the interconnect supports a secondary BGP in the same address family (IPv4/IPv6).
-
#interconnect_id ⇒ String
The ID of the interconnect.
-
#interconnect_name ⇒ String
The name of the interconnect.
-
#interconnect_state ⇒ String
The state of the interconnect.
-
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
-
#lag_id ⇒ String
The ID of the LAG.
-
#loa_issue_time ⇒ Time
The time of the most recent call to DescribeLoa for this connection.
-
#location ⇒ String
The location of the connection.
-
#mac_sec_capable ⇒ Boolean
Indicates whether the interconnect supports MAC Security (MACsec).
-
#mac_sec_keys ⇒ Array<Types::MacSecKey>
The MAC Security (MACsec) security keys.
-
#port_encryption_status ⇒ String
The MAC Security (MACsec) port link status.
-
#provider_name ⇒ String
The name of the service provider associated with the interconnect.
-
#region ⇒ String
The Amazon Web Services Region where the connection is located.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the interconnect.
Instance Attribute Details
#aws_device ⇒ String
The Direct Connect endpoint on which the physical connection terminates.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#aws_device_v2 ⇒ String
The Direct Connect endpoint that terminates the physical connection.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#bandwidth ⇒ String
The bandwidth of the connection.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#encryption_mode ⇒ String
The MAC Security (MACsec) encryption mode.
The valid values are ‘no_encrypt`, `should_encrypt`, and `must_encrypt`.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#has_logical_redundancy ⇒ String
Indicates whether the interconnect supports a secondary BGP in the same address family (IPv4/IPv6).
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#interconnect_id ⇒ String
The ID of the interconnect.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#interconnect_name ⇒ String
The name of the interconnect.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#interconnect_state ⇒ String
The state of the interconnect. The following are the possible values:
-
‘requested`: The initial state of an interconnect. The interconnect stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.
-
‘pending`: The interconnect is approved, and is being initialized.
-
‘available`: The network link is up, and the interconnect is ready for use.
-
‘down`: The network link is down.
-
‘deleting`: The interconnect is being deleted.
-
‘deleted`: The interconnect is deleted.
-
‘unknown`: The state of the interconnect is not available.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#lag_id ⇒ String
The ID of the LAG.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#loa_issue_time ⇒ Time
The time of the most recent call to DescribeLoa for this connection.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the connection.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#mac_sec_capable ⇒ Boolean
Indicates whether the interconnect supports MAC Security (MACsec).
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#mac_sec_keys ⇒ Array<Types::MacSecKey>
The MAC Security (MACsec) security keys.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#port_encryption_status ⇒ String
The MAC Security (MACsec) port link status.
The valid values are ‘Encryption Up`, which means that there is an active Connection Key Name, or `Encryption Down`.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the interconnect.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region where the connection is located.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the interconnect.
2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2707 class Interconnect < Struct.new( :interconnect_id, :interconnect_name, :interconnect_state, :region, :location, :bandwidth, :loa_issue_time, :lag_id, :aws_device, :jumbo_frame_capable, :aws_device_v2, :aws_logical_device_id, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :port_encryption_status, :encryption_mode, :mac_sec_keys) SENSITIVE = [] include Aws::Structure end |