Class: Aws::DirectConnect::Types::Lag
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::Lag
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a link aggregation group (LAG).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allows_hosted_connections ⇒ Boolean
Indicates whether the LAG can host other connections.
-
#aws_device ⇒ String
The Direct Connect endpoint that hosts the LAG.
-
#aws_device_v2 ⇒ String
The Direct Connect endpoint that hosts the LAG.
-
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection.
-
#connections ⇒ Array<Types::Connection>
The connections bundled by the LAG.
-
#connections_bandwidth ⇒ String
The individual bandwidth of the physical connections bundled by the LAG.
-
#encryption_mode ⇒ String
The LAG MAC Security (MACsec) encryption mode.
-
#has_logical_redundancy ⇒ String
Indicates whether the LAG supports a secondary BGP peer in the same address family (IPv4/IPv6).
-
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
-
#lag_id ⇒ String
The ID of the LAG.
-
#lag_name ⇒ String
The name of the LAG.
-
#lag_state ⇒ String
The state of the LAG.
-
#location ⇒ String
The location of the LAG.
-
#mac_sec_capable ⇒ Boolean
Indicates whether the LAG supports MAC Security (MACsec).
-
#mac_sec_keys ⇒ Array<Types::MacSecKey>
The MAC Security (MACsec) security keys associated with the LAG.
-
#minimum_links ⇒ Integer
The minimum number of physical dedicated connections that must be operational for the LAG itself to be operational.
-
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG.
-
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the LAG.
-
#prefix_pool_size_ipv_4 ⇒ Integer
The total number of inbound IPv4 route prefixes you can allocate across the virtual interfaces on the LAG.
-
#prefix_pool_size_ipv_6 ⇒ Integer
The total number of inbound IPv6 route prefixes you can allocate across the virtual interfaces on the LAG.
-
#prefix_pool_unallocated_count_ipv_4 ⇒ Integer
The number of inbound IPv4 route prefixes in the LAG prefix pool not yet allocated to a virtual interface.
-
#prefix_pool_unallocated_count_ipv_6 ⇒ Integer
The number of inbound IPv6 route prefixes in the LAG prefix pool not yet allocated to a virtual interface.
-
#provider_name ⇒ String
The name of the service provider associated with the LAG.
-
#rate_limiter_status ⇒ Types::RateLimiterStatus
The rate limiter status for the LAG, including how many rate limiters are in use and the maximum allowed.
-
#region ⇒ String
The Amazon Web Services Region where the connection is located.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the LAG.
Instance Attribute Details
#allows_hosted_connections ⇒ Boolean
Indicates whether the LAG can host other connections.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#aws_device ⇒ String
The Direct Connect endpoint that hosts the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#aws_device_v2 ⇒ String
The Direct Connect endpoint that hosts the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#connections ⇒ Array<Types::Connection>
The connections bundled by the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#connections_bandwidth ⇒ String
The individual bandwidth of the physical connections bundled by the LAG. The possible values are 1Gbps, 10Gbps, 100Gbps, or 400 Gbps..
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#encryption_mode ⇒ String
The LAG MAC Security (MACsec) encryption mode.
The valid values are no_encrypt, should_encrypt, and
must_encrypt.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#has_logical_redundancy ⇒ String
Indicates whether the LAG supports a secondary BGP peer in the same address family (IPv4/IPv6).
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#lag_id ⇒ String
The ID of the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#lag_name ⇒ String
The name of the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#lag_state ⇒ String
The state of the LAG. The following are the possible values:
-
requested: The initial state of a LAG. The LAG stays in the requested state until the Letter of Authorization (LOA) is available. -
pending: The LAG has been approved and is being initialized. -
available: The network link is established and the LAG is ready for use. -
down: The network link is down. -
deleting: The LAG is being deleted. -
deleted: The LAG is deleted. -
unknown: The state of the LAG is not available.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#mac_sec_capable ⇒ Boolean
Indicates whether the LAG supports MAC Security (MACsec).
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#mac_sec_keys ⇒ Array<Types::MacSecKey>
The MAC Security (MACsec) security keys associated with the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#minimum_links ⇒ Integer
The minimum number of physical dedicated connections that must be operational for the LAG itself to be operational.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG. You can have a maximum of four connections when the port speed is 1 Gbps or 10 Gbps, or two when the port speed is 100 Gbps or 400 Gbps.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#prefix_pool_size_ipv_4 ⇒ Integer
The total number of inbound IPv4 route prefixes you can allocate across the virtual interfaces on the LAG. Not applicable to LAGs that are interconnects and support hosted connections.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#prefix_pool_size_ipv_6 ⇒ Integer
The total number of inbound IPv6 route prefixes you can allocate across the virtual interfaces on the LAG. Not applicable to LAGs that are interconnects and support hosted connections.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#prefix_pool_unallocated_count_ipv_4 ⇒ Integer
The number of inbound IPv4 route prefixes in the LAG prefix pool not yet allocated to a virtual interface. Not applicable to LAGs that are interconnects and support hosted connections.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#prefix_pool_unallocated_count_ipv_6 ⇒ Integer
The number of inbound IPv6 route prefixes in the LAG prefix pool not yet allocated to a virtual interface. Not applicable to LAGs that are interconnects and support hosted connections.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#rate_limiter_status ⇒ Types::RateLimiterStatus
The rate limiter status for the LAG, including how many rate limiters are in use and the maximum allowed.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region where the connection is located.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the LAG.
2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2951 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :prefix_pool_size_ipv_4, :prefix_pool_size_ipv_6, :prefix_pool_unallocated_count_ipv_4, :prefix_pool_unallocated_count_ipv_6, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |