Class: Aws::DirectConnect::Types::Lag
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::Lag
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a link aggregation group (LAG).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allows_hosted_connections ⇒ Boolean
Indicates whether the LAG can host other connections.
-
#aws_device ⇒ String
The Direct Connect endpoint that hosts the LAG.
-
#aws_device_v2 ⇒ String
The Direct Connect endpoint that hosts the LAG.
-
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection.
-
#connections ⇒ Array<Types::Connection>
The connections bundled by the LAG.
-
#connections_bandwidth ⇒ String
The individual bandwidth of the physical connections bundled by the LAG.
-
#encryption_mode ⇒ String
The LAG MAC Security (MACsec) encryption mode.
-
#has_logical_redundancy ⇒ String
Indicates whether the LAG supports a secondary BGP peer in the same address family (IPv4/IPv6).
-
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
-
#lag_id ⇒ String
The ID of the LAG.
-
#lag_name ⇒ String
The name of the LAG.
-
#lag_state ⇒ String
The state of the LAG.
-
#location ⇒ String
The location of the LAG.
-
#mac_sec_capable ⇒ Boolean
Indicates whether the LAG supports MAC Security (MACsec).
-
#mac_sec_keys ⇒ Array<Types::MacSecKey>
The MAC Security (MACsec) security keys associated with the LAG.
-
#minimum_links ⇒ Integer
The minimum number of physical dedicated connections that must be operational for the LAG itself to be operational.
-
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG.
-
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the LAG.
-
#provider_name ⇒ String
The name of the service provider associated with the LAG.
-
#rate_limiter_status ⇒ Types::RateLimiterStatus
The rate limiter status for the LAG, including how many rate limiters are in use and the maximum allowed.
-
#region ⇒ String
The Amazon Web Services Region where the connection is located.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the LAG.
Instance Attribute Details
#allows_hosted_connections ⇒ Boolean
Indicates whether the LAG can host other connections.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#aws_device ⇒ String
The Direct Connect endpoint that hosts the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#aws_device_v2 ⇒ String
The Direct Connect endpoint that hosts the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#connections ⇒ Array<Types::Connection>
The connections bundled by the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#connections_bandwidth ⇒ String
The individual bandwidth of the physical connections bundled by the LAG. The possible values are 1Gbps, 10Gbps, 100Gbps, or 400 Gbps..
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#encryption_mode ⇒ String
The LAG MAC Security (MACsec) encryption mode.
The valid values are no_encrypt, should_encrypt, and
must_encrypt.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#has_logical_redundancy ⇒ String
Indicates whether the LAG supports a secondary BGP peer in the same address family (IPv4/IPv6).
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#lag_id ⇒ String
The ID of the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#lag_name ⇒ String
The name of the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#lag_state ⇒ String
The state of the LAG. The following are the possible values:
-
requested: The initial state of a LAG. The LAG stays in the requested state until the Letter of Authorization (LOA) is available. -
pending: The LAG has been approved and is being initialized. -
available: The network link is established and the LAG is ready for use. -
down: The network link is down. -
deleting: The LAG is being deleted. -
deleted: The LAG is deleted. -
unknown: The state of the LAG is not available.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#mac_sec_capable ⇒ Boolean
Indicates whether the LAG supports MAC Security (MACsec).
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#mac_sec_keys ⇒ Array<Types::MacSecKey>
The MAC Security (MACsec) security keys associated with the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#minimum_links ⇒ Integer
The minimum number of physical dedicated connections that must be operational for the LAG itself to be operational.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#number_of_connections ⇒ Integer
The number of physical dedicated connections initially provisioned and bundled by the LAG. You can have a maximum of four connections when the port speed is 1 Gbps or 10 Gbps, or two when the port speed is 100 Gbps or 400 Gbps.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the service provider associated with the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#rate_limiter_status ⇒ Types::RateLimiterStatus
The rate limiter status for the LAG, including how many rate limiters are in use and the maximum allowed.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region where the connection is located.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the LAG.
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-directconnect/types.rb', line 2892 class Lag < Struct.new( :connections_bandwidth, :number_of_connections, :lag_id, :owner_account, :lag_name, :lag_state, :location, :region, :minimum_links, :aws_device, :aws_device_v2, :aws_logical_device_id, :connections, :allows_hosted_connections, :jumbo_frame_capable, :has_logical_redundancy, :tags, :provider_name, :mac_sec_capable, :encryption_mode, :mac_sec_keys, :rate_limiter_status) SENSITIVE = [] include Aws::Structure end |