Class: Aws::DirectConnect::Types::Lag

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Information about a link aggregation group (LAG).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allows_hosted_connectionsBoolean

Indicates whether the LAG can host other connections.

Returns:

  • (Boolean)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#aws_deviceString

The Direct Connect endpoint that hosts the LAG.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#aws_device_v2String

The Direct Connect endpoint that hosts the LAG.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#aws_logical_device_idString

The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#connectionsArray<Types::Connection>

The connections bundled by the LAG.

Returns:



2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#connections_bandwidthString

The individual bandwidth of the physical connections bundled by the LAG. The possible values are 1Gbps, 10Gbps, 100Gbps, or 400 Gbps..

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_modeString

The LAG MAC Security (MACsec) encryption mode.

The valid values are ‘no_encrypt`, `should_encrypt`, and `must_encrypt`.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#has_logical_redundancyString

Indicates whether the LAG supports a secondary BGP peer in the same address family (IPv4/IPv6).

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#jumbo_frame_capableBoolean

Indicates whether jumbo frames are supported.

Returns:

  • (Boolean)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#lag_idString

The ID of the LAG.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#lag_nameString

The name of the LAG.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#lag_stateString

The state of the LAG. The following are the possible values:

  • ‘requested`: The initial state of a LAG. The LAG stays in the requested state until the Letter of Authorization (LOA) is available.

  • ‘pending`: The LAG has been approved and is being initialized.

  • ‘available`: The network link is established and the LAG is ready for use.

  • ‘down`: The network link is down.

  • ‘deleting`: The LAG is being deleted.

  • ‘deleted`: The LAG is deleted.

  • ‘unknown`: The state of the LAG is not available.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The location of the LAG.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#mac_sec_capableBoolean

Indicates whether the LAG supports MAC Security (MACsec).

Returns:

  • (Boolean)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#mac_sec_keysArray<Types::MacSecKey>

The MAC Security (MACsec) security keys associated with the LAG.

Returns:



2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

The minimum number of physical dedicated connections that must be operational for the LAG itself to be operational.

Returns:

  • (Integer)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_connectionsInteger

The number of physical dedicated connections initially provisioned and bundled by the LAG. You can have a maximum of four connections when the port speed is 1 Gbps or 10 Gbps, or two when the port speed is 100 Gbps or 400 Gbps.

Returns:

  • (Integer)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#owner_accountString

The ID of the Amazon Web Services account that owns the LAG.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The name of the service provider associated with the LAG.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#rate_limiter_statusTypes::RateLimiterStatus

The rate limiter status for the LAG, including how many rate limiters are in use and the maximum allowed.



2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region where the connection is located.

Returns:

  • (String)


2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the LAG.

Returns:



2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/aws-sdk-directconnect/types.rb', line 2870

class Lag < Struct.new(
  :connections_bandwidth,
  :number_of_connections,
  :lag_id,
  :owner_account,
  :lag_name,
  :lag_state,
  :location,
  :region,
  :minimum_links,
  :aws_device,
  :aws_device_v2,
  :aws_logical_device_id,
  :connections,
  :allows_hosted_connections,
  :jumbo_frame_capable,
  :has_logical_redundancy,
  :tags,
  :provider_name,
  :mac_sec_capable,
  :encryption_mode,
  :mac_sec_keys,
  :rate_limiter_status)
  SENSITIVE = []
  include Aws::Structure
end