Class: Aws::DirectConnect::Types::LimitExceededException
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::DirectConnect::Types::LimitExceededException
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
The rate limiter limit has been exceeded for the connection. You cannot add more rate limiters to virtual interfaces on this connection.