Class: Aws::DirectConnect::Types::Location
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::Location
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about an Direct Connect location.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#available_mac_sec_port_speeds ⇒ Array<String>
The available MAC Security (MACsec) port speeds for the location.
-
#available_port_speeds ⇒ Array<String>
The available port speeds for the location.
-
#available_providers ⇒ Array<String>
The name of the service provider for the location.
-
#location_code ⇒ String
The code for the location.
-
#location_name ⇒ String
The name of the location.
-
#region ⇒ String
The Amazon Web Services Region for the location.
Instance Attribute Details
#available_mac_sec_port_speeds ⇒ Array<String>
The available MAC Security (MACsec) port speeds for the location.
3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3034 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds) SENSITIVE = [] include Aws::Structure end |
#available_port_speeds ⇒ Array<String>
The available port speeds for the location.
3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3034 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds) SENSITIVE = [] include Aws::Structure end |
#available_providers ⇒ Array<String>
The name of the service provider for the location.
3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3034 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds) SENSITIVE = [] include Aws::Structure end |
#location_code ⇒ String
The code for the location.
3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3034 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds) SENSITIVE = [] include Aws::Structure end |
#location_name ⇒ String
The name of the location. This includes the name of the colocation partner and the physical site of the building.
3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3034 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region for the location.
3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3034 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds) SENSITIVE = [] include Aws::Structure end |