Class: Aws::DirectConnect::Types::Location
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::Location
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about an Direct Connect location.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#available_billing_modes ⇒ Array<Types::AvailableBillingMode>
The billing modes available at the location, including the port speeds and Amazon Web Services Regions supported by each mode.
-
#available_mac_sec_port_speeds ⇒ Array<String>
The available MAC Security (MACsec) port speeds for the location.
-
#available_port_speeds ⇒ Array<String>
The available port speeds for the location.
-
#available_providers ⇒ Array<String>
The name of the service provider for the location.
-
#location_code ⇒ String
The code for the location.
-
#location_name ⇒ String
The name of the location.
-
#region ⇒ String
The Amazon Web Services Region for the location.
Instance Attribute Details
#available_billing_modes ⇒ Array<Types::AvailableBillingMode>
The billing modes available at the location, including the port speeds and Amazon Web Services Regions supported by each mode.
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3471 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds, :available_billing_modes) SENSITIVE = [] include Aws::Structure end |
#available_mac_sec_port_speeds ⇒ Array<String>
The available MAC Security (MACsec) port speeds for the location.
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3471 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds, :available_billing_modes) SENSITIVE = [] include Aws::Structure end |
#available_port_speeds ⇒ Array<String>
The available port speeds for the location.
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3471 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds, :available_billing_modes) SENSITIVE = [] include Aws::Structure end |
#available_providers ⇒ Array<String>
The name of the service provider for the location.
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3471 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds, :available_billing_modes) SENSITIVE = [] include Aws::Structure end |
#location_code ⇒ String
The code for the location.
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3471 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds, :available_billing_modes) SENSITIVE = [] include Aws::Structure end |
#location_name ⇒ String
The name of the location. This includes the name of the colocation partner and the physical site of the building.
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3471 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds, :available_billing_modes) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region for the location.
3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3471 class Location < Struct.new( :location_code, :location_name, :region, :available_port_speeds, :available_providers, :available_mac_sec_port_speeds, :available_billing_modes) SENSITIVE = [] include Aws::Structure end |