Class: Aws::DirectConnect::Types::NewPrivateVirtualInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::NewPrivateVirtualInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
When making an API call, you may pass NewPrivateVirtualInterface data as a hash:
{
virtual_interface_name: "VirtualInterfaceName", # required
vlan: 1, # required
asn: 1, # required
mtu: 1,
auth_key: "BGPAuthKey",
amazon_address: "AmazonAddress",
customer_address: "CustomerAddress",
address_family: "ipv4", # accepts ipv4, ipv6
virtual_gateway_id: "VirtualGatewayId",
direct_connect_gateway_id: "DirectConnectGatewayId",
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
enable_site_link: false,
}
Information about a private virtual interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#asn ⇒ Integer
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#enable_site_link ⇒ Boolean
Indicates whether to enable or disable SiteLink.
-
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the private virtual interface.
-
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway.
-
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
The valid values are 1-2147483647.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#enable_site_link ⇒ Boolean
Indicates whether to enable or disable SiteLink.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 9001. The default value is 1500.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the private virtual interface.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3540 class NewPrivateVirtualInterface < Struct.new( :virtual_interface_name, :vlan, :asn, :mtu, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_gateway_id, :direct_connect_gateway_id, :tags, :enable_site_link) SENSITIVE = [] include Aws::Structure end |