Class: Aws::DirectConnect::Types::RateLimiterStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::RateLimiterStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Contains information about the rate limiter status for a connection, including the maximum number of rate limiters allowed, the number currently in use, and the remaining capacity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#in_use ⇒ Integer
The number of rate limiters currently in use on the connection.
-
#max_allowed ⇒ Integer
The maximum number of rate limiters allowed on the connection.
-
#remaining ⇒ Integer
The number of rate limiters remaining (available) on the connection.
-
#total_bandwidth ⇒ String
The total bandwidth allocated across all rate limiters on the connection.
Instance Attribute Details
#in_use ⇒ Integer
The number of rate limiters currently in use on the connection.
3836 3837 3838 3839 3840 3841 3842 3843 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3836 class RateLimiterStatus < Struct.new( :max_allowed, :in_use, :remaining, :total_bandwidth) SENSITIVE = [] include Aws::Structure end |
#max_allowed ⇒ Integer
The maximum number of rate limiters allowed on the connection.
3836 3837 3838 3839 3840 3841 3842 3843 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3836 class RateLimiterStatus < Struct.new( :max_allowed, :in_use, :remaining, :total_bandwidth) SENSITIVE = [] include Aws::Structure end |
#remaining ⇒ Integer
The number of rate limiters remaining (available) on the connection.
3836 3837 3838 3839 3840 3841 3842 3843 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3836 class RateLimiterStatus < Struct.new( :max_allowed, :in_use, :remaining, :total_bandwidth) SENSITIVE = [] include Aws::Structure end |
#total_bandwidth ⇒ String
The total bandwidth allocated across all rate limiters on the connection.
3836 3837 3838 3839 3840 3841 3842 3843 |
# File 'lib/aws-sdk-directconnect/types.rb', line 3836 class RateLimiterStatus < Struct.new( :max_allowed, :in_use, :remaining, :total_bandwidth) SENSITIVE = [] include Aws::Structure end |