Class: Aws::DirectConnect::Types::Route

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Information about a route for a virtual interface.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#address_familyString

The address family of the route.

The valid values are ipv4 and ipv6.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-directconnect/types.rb', line 3981

class Route < Struct.new(
  :cidr,
  :route_direction,
  :address_family,
  :as_path,
  :communities,
  :aws_logical_device_id,
  :route_installed_at)
  SENSITIVE = []
  include Aws::Structure
end

#as_pathArray<Types::AsPathSegment>

The autonomous system (AS) path of the route.

Returns:



3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-directconnect/types.rb', line 3981

class Route < Struct.new(
  :cidr,
  :route_direction,
  :address_family,
  :as_path,
  :communities,
  :aws_logical_device_id,
  :route_installed_at)
  SENSITIVE = []
  include Aws::Structure
end

#aws_logical_device_idString

The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-directconnect/types.rb', line 3981

class Route < Struct.new(
  :cidr,
  :route_direction,
  :address_family,
  :as_path,
  :communities,
  :aws_logical_device_id,
  :route_installed_at)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

The CIDR (prefix) of the route.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-directconnect/types.rb', line 3981

class Route < Struct.new(
  :cidr,
  :route_direction,
  :address_family,
  :as_path,
  :communities,
  :aws_logical_device_id,
  :route_installed_at)
  SENSITIVE = []
  include Aws::Structure
end

#communitiesArray<String>

The BGP communities associated with the route.

Returns:

  • (Array<String>)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-directconnect/types.rb', line 3981

class Route < Struct.new(
  :cidr,
  :route_direction,
  :address_family,
  :as_path,
  :communities,
  :aws_logical_device_id,
  :route_installed_at)
  SENSITIVE = []
  include Aws::Structure
end

#route_directionString

The direction of the route.

The valid values are accepted (received from the customer network) and advertised (advertised to the customer network).

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-directconnect/types.rb', line 3981

class Route < Struct.new(
  :cidr,
  :route_direction,
  :address_family,
  :as_path,
  :communities,
  :aws_logical_device_id,
  :route_installed_at)
  SENSITIVE = []
  include Aws::Structure
end

#route_installed_atTime

The time when the route was installed. The value is displayed in UTC format.

Returns:

  • (Time)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-directconnect/types.rb', line 3981

class Route < Struct.new(
  :cidr,
  :route_direction,
  :address_family,
  :as_path,
  :communities,
  :aws_logical_device_id,
  :route_installed_at)
  SENSITIVE = []
  include Aws::Structure
end