Class: Aws::DirectConnect::Types::UpdateLagRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::UpdateLagRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Note:
When making an API call, you may pass UpdateLagRequest data as a hash:
{
lag_id: "LagId", # required
lag_name: "LagName",
minimum_links: 1,
encryption_mode: "EncryptionMode",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_mode ⇒ String
The LAG MAC Security (MACsec) encryption mode.
-
#lag_id ⇒ String
The ID of the LAG.
-
#lag_name ⇒ String
The name of the LAG.
-
#minimum_links ⇒ Integer
The minimum number of physical connections that must be operational for the LAG itself to be operational.
Instance Attribute Details
#encryption_mode ⇒ String
The LAG MAC Security (MACsec) encryption mode.
Amazon Web Services applies the value to all connections which are part of the LAG.
4409 4410 4411 4412 4413 4414 4415 4416 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4409 class UpdateLagRequest < Struct.new( :lag_id, :lag_name, :minimum_links, :encryption_mode) SENSITIVE = [] include Aws::Structure end |
#lag_id ⇒ String
The ID of the LAG.
4409 4410 4411 4412 4413 4414 4415 4416 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4409 class UpdateLagRequest < Struct.new( :lag_id, :lag_name, :minimum_links, :encryption_mode) SENSITIVE = [] include Aws::Structure end |
#lag_name ⇒ String
The name of the LAG.
4409 4410 4411 4412 4413 4414 4415 4416 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4409 class UpdateLagRequest < Struct.new( :lag_id, :lag_name, :minimum_links, :encryption_mode) SENSITIVE = [] include Aws::Structure end |
#minimum_links ⇒ Integer
The minimum number of physical connections that must be operational for the LAG itself to be operational.
4409 4410 4411 4412 4413 4414 4415 4416 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4409 class UpdateLagRequest < Struct.new( :lag_id, :lag_name, :minimum_links, :encryption_mode) SENSITIVE = [] include Aws::Structure end |