Class: Aws::DirectConnect::Types::UpdateLagRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directconnect/types.rb

Overview

Note:

When making an API call, you may pass UpdateLagRequest data as a hash:

{
  lag_id: "LagId", # required
  lag_name: "LagName",
  minimum_links: 1,
  encryption_mode: "EncryptionMode",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_modeString

The LAG MAC Security (MACsec) encryption mode.

Amazon Web Services applies the value to all connections which are part of the LAG.

Returns:

  • (String)


4409
4410
4411
4412
4413
4414
4415
4416
# File 'lib/aws-sdk-directconnect/types.rb', line 4409

class UpdateLagRequest < Struct.new(
  :lag_id,
  :lag_name,
  :minimum_links,
  :encryption_mode)
  SENSITIVE = []
  include Aws::Structure
end

#lag_idString

The ID of the LAG.

Returns:

  • (String)


4409
4410
4411
4412
4413
4414
4415
4416
# File 'lib/aws-sdk-directconnect/types.rb', line 4409

class UpdateLagRequest < Struct.new(
  :lag_id,
  :lag_name,
  :minimum_links,
  :encryption_mode)
  SENSITIVE = []
  include Aws::Structure
end

#lag_nameString

The name of the LAG.

Returns:

  • (String)


4409
4410
4411
4412
4413
4414
4415
4416
# File 'lib/aws-sdk-directconnect/types.rb', line 4409

class UpdateLagRequest < Struct.new(
  :lag_id,
  :lag_name,
  :minimum_links,
  :encryption_mode)
  SENSITIVE = []
  include Aws::Structure
end

The minimum number of physical connections that must be operational for the LAG itself to be operational.

Returns:

  • (Integer)


4409
4410
4411
4412
4413
4414
4415
4416
# File 'lib/aws-sdk-directconnect/types.rb', line 4409

class UpdateLagRequest < Struct.new(
  :lag_id,
  :lag_name,
  :minimum_links,
  :encryption_mode)
  SENSITIVE = []
  include Aws::Structure
end