Class: Aws::DirectConnect::Types::VirtualInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectConnect::Types::VirtualInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directconnect/types.rb
Overview
Information about a virtual interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_family ⇒ String
The address family for the BGP peer.
-
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
-
#amazon_side_asn ⇒ Integer
The autonomous system number (AS) for the Amazon side of the connection.
-
#asn ⇒ Integer
The autonomous system number (ASN).
-
#asn_long ⇒ Integer
The long ASN for the virtual interface.
-
#auth_key ⇒ String
The authentication key for BGP configuration.
-
#aws_device_v2 ⇒ String
The Direct Connect endpoint that terminates the physical connection.
-
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection.
-
#bgp_peers ⇒ Array<Types::BGPPeer>
The BGP peers configured on this virtual interface.
-
#connection_id ⇒ String
The ID of the connection.
-
#customer_address ⇒ String
The IP address assigned to the customer interface.
-
#customer_router_config ⇒ String
The customer router configuration.
-
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
-
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
-
#location ⇒ String
The location of the connection.
-
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes.
-
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the virtual interface.
-
#rate_limit ⇒ String
The rate limit (bandwidth allocation) applied to the virtual interface.
-
#region ⇒ String
The Amazon Web Services Region where the virtual interface is located.
-
#route_filter_prefixes ⇒ Array<Types::RouteFilterPrefix>
The routes to be advertised to the Amazon Web Services network in this Region.
-
#site_link_enabled ⇒ Boolean
Indicates whether SiteLink is enabled.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the virtual interface.
-
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway.
-
#virtual_interface_id ⇒ String
The ID of the virtual interface.
-
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network.
-
#virtual_interface_state ⇒ String
The state of the virtual interface.
-
#virtual_interface_type ⇒ String
The type of virtual interface.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#address_family ⇒ String
The address family for the BGP peer.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#amazon_address ⇒ String
The IP address assigned to the Amazon interface.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#amazon_side_asn ⇒ Integer
The autonomous system number (AS) for the Amazon side of the connection.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ Integer
The autonomous system number (ASN). The valid range is from 1 to 2147483646 for Border Gateway Protocol (BGP) configuration. If you provide a number greater than the maximum, an error is returned. Use ‘asnLong` instead.
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
-
If you enter a 4-byte ASN for the ‘asn` parameter, the API returns an error.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#asn_long ⇒ Integer
The long ASN for the virtual interface. The valid range is from 1 to 4294967294 for BGP configuration.
Note the following limitations when using ‘asnLong`:
-
You can use ‘asnLong` or `asn`, but not both. We recommend using `asnLong` as it supports a greater pool of numbers.
-
‘asnLong` accepts any valid ASN value, regardless if it’s 2-byte or 4-byte.
-
When using a 4-byte ‘asnLong`, the API response returns `0` for the legacy `asn` attribute since 4-byte ASN values exceed the maximum supported value of 2,147,483,647.
-
If you are using a 2-byte ASN, the API response will include the 2-byte value for both the ‘asn` and `asnLong` fields.
-
If you provide a value in the same API call for both ‘asn` and `asnLong`, the API will only accept the value for `asnLong`.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#auth_key ⇒ String
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#aws_device_v2 ⇒ String
The Direct Connect endpoint that terminates the physical connection.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#aws_logical_device_id ⇒ String
The Direct Connect endpoint that terminates the logical connection. This device might be different than the device that terminates the physical connection.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#bgp_peers ⇒ Array<Types::BGPPeer>
The BGP peers configured on this virtual interface.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of the connection.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#customer_address ⇒ String
The IP address assigned to the customer interface.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#customer_router_config ⇒ String
The customer router configuration.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#direct_connect_gateway_id ⇒ String
The ID of the Direct Connect gateway.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#jumbo_frame_capable ⇒ Boolean
Indicates whether jumbo frames are supported.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the connection.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#mtu ⇒ Integer
The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 8500. The default value is 1500
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The ID of the Amazon Web Services account that owns the virtual interface.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#rate_limit ⇒ String
The rate limit (bandwidth allocation) applied to the virtual interface. The possible values are ‘50 Mbps`, `100 Mbps`, `200 Mbps`, `300 Mbps`, `400 Mbps`, `500 Mbps`, `1 Gbps`, `2 Gbps`, `5 Gbps`, or `10 Gbps`.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region where the virtual interface is located.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#route_filter_prefixes ⇒ Array<Types::RouteFilterPrefix>
The routes to be advertised to the Amazon Web Services network in this Region. Applies to public virtual interfaces.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#site_link_enabled ⇒ Boolean
Indicates whether SiteLink is enabled.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the virtual interface.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_gateway_id ⇒ String
The ID of the virtual private gateway. Applies only to private virtual interfaces.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_id ⇒ String
The ID of the virtual interface.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_name ⇒ String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_state ⇒ String
The state of the virtual interface. The following are the possible values:
-
‘confirming`: The creation of the virtual interface is pending confirmation from the virtual interface owner. If the owner of the virtual interface is different from the owner of the connection on which it is provisioned, then the virtual interface will remain in this state until it is confirmed by the virtual interface owner.
-
‘verifying`: This state only applies to public virtual interfaces. Each public virtual interface needs validation before the virtual interface can be created.
-
‘pending`: A virtual interface is in this state from the time that it is created until the virtual interface is ready to forward traffic.
-
‘available`: A virtual interface that is able to forward traffic.
-
‘down`: A virtual interface that is BGP down.
-
‘testing`: A virtual interface is in this state immediately after calling StartBgpFailoverTest and remains in this state during the duration of the test.
-
‘deleting`: A virtual interface is in this state immediately after calling DeleteVirtualInterface until it can no longer forward traffic.
-
‘deleted`: A virtual interface that cannot forward traffic.
-
‘rejected`: The virtual interface owner has declined creation of the virtual interface. If a virtual interface in the `Confirming` state is deleted by the virtual interface owner, the virtual interface enters the `Rejected` state.
-
‘unknown`: The state of the virtual interface is not available.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#virtual_interface_type ⇒ String
The type of virtual interface. The possible values are ‘private`, `public` and `transit`.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 |
# File 'lib/aws-sdk-directconnect/types.rb', line 4458 class VirtualInterface < Struct.new( :owner_account, :virtual_interface_id, :location, :connection_id, :virtual_interface_type, :virtual_interface_name, :vlan, :asn, :asn_long, :amazon_side_asn, :auth_key, :amazon_address, :customer_address, :address_family, :virtual_interface_state, :customer_router_config, :mtu, :jumbo_frame_capable, :virtual_gateway_id, :direct_connect_gateway_id, :route_filter_prefixes, :bgp_peers, :region, :aws_device_v2, :aws_logical_device_id, :tags, :site_link_enabled, :rate_limit) SENSITIVE = [] include Aws::Structure end |